/********************************************************************************
** Form generated from reading UI file 'TonemappingPanel.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TONEMAPPINGPANEL_H
#define UI_TONEMAPPINGPANEL_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QToolBox>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_TonemappingPanel
{
public:
    QGridLayout *gridLayout_13;
    QFrame *line;
    QGroupBox *tonemapGroupBox;
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout_operator;
    QComboBox *cmbOperators;
    QLabel *lblOperators;
    QStackedWidget *stackedWidget_operators;
    QWidget *page_mantiuk06;
    QGridLayout *gridLayout_6;
    QGridLayout *gridLayout_2;
    QLabel *label_23;
    QCheckBox *contrastEqualizCheckBox;
    QSlider *detailFactorSlider;
    QSlider *contrastFactorSlider;
    QLabel *label_desc_df;
    QLabel *label_22;
    QSlider *saturationFactorSlider;
    QDoubleSpinBox *contrastFactordsb;
    QDoubleSpinBox *saturationFactordsb;
    QDoubleSpinBox *detailFactordsb;
    QSpacerItem *verticalSpacer_3;
    QWidget *page_mantiuk08;
    QGridLayout *gridLayout_9;
    QGridLayout *gridLayout;
    QComboBox *displayComboBox;
    QLabel *label_3;
    QLabel *label_4;
    QCheckBox *luminanceLevelCheckBox;
    QLabel *label_5;
    QDoubleSpinBox *luminanceLevelDSB;
    QDoubleSpinBox *contrastEnhancementDSB;
    QSlider *luminanceLevelSlider;
    QSlider *contrastEnhancementSlider;
    QDoubleSpinBox *colorSaturationDSB;
    QSlider *colorSaturationSlider;
    QLabel *label_6;
    QSpacerItem *verticalSpacer_4;
    QWidget *page_fattal;
    QGridLayout *gridLayout_10;
    QGridLayout *gridLayout_18;
    QLabel *label_17;
    QSlider *alphaSlider;
    QDoubleSpinBox *alphadsb;
    QLabel *label_19;
    QSlider *betaSlider;
    QDoubleSpinBox *betadsb;
    QDoubleSpinBox *saturation2dsb;
    QSlider *saturation2Slider;
    QLabel *label_18;
    QLabel *label_20;
    QSlider *noiseSlider;
    QCheckBox *fftVersionCheckBox;
    QDoubleSpinBox *noisedsb;
    QSpacerItem *verticalSpacer_5;
    QWidget *page_ferradans;
    QGridLayout *gridLayout_11;
    QGridLayout *gridLayout_16;
    QSlider *rhoSlider;
    QLabel *label_8;
    QSlider *inv_alphaSlider;
    QLabel *label_7;
    QDoubleSpinBox *rhodsb;
    QDoubleSpinBox *inv_alphadsb;
    QSpacerItem *verticalSpacer_6;
    QWidget *page_drago;
    QGridLayout *gridLayout_21;
    QGridLayout *gridLayout_7;
    QLabel *label_11;
    QSlider *biasSlider;
    QDoubleSpinBox *biasdsb;
    QSpacerItem *verticalSpacer_12;
    QWidget *page_durand;
    QGridLayout *gridLayout_8;
    QGridLayout *gridLayout_14;
    QLabel *label_spatialsigma;
    QLabel *label_basecontrast;
    QDoubleSpinBox *basedsb;
    QDoubleSpinBox *spatialdsb;
    QSlider *baseSlider;
    QSlider *spatialSlider;
    QLabel *label_rangesigma;
    QSlider *rangeSlider;
    QDoubleSpinBox *rangedsb;
    QSpacerItem *verticalSpacer_16;
    QWidget *page_reinhard02;
    QGridLayout *gridLayout_12;
    QGridLayout *gridLayout_22;
    QSlider *phiSlider;
    QSpacerItem *verticalSpacer_8;
    QDoubleSpinBox *phidsb;
    QDoubleSpinBox *range2dsb;
    QDoubleSpinBox *keydsb;
    QDoubleSpinBox *lowerdsb;
    QDoubleSpinBox *upperdsb;
    QSlider *range2Slider;
    QLabel *label_phi;
    QLabel *label_key;
    QLabel *label_lowerscale;
    QSlider *keySlider;
    QSlider *lowerSlider;
    QLabel *label_upperscale;
    QSlider *upperSlider;
    QHBoxLayout *horizontalLayout;
    QCheckBox *usescalescheckbox;
    QLabel *label_range;
    QSpacerItem *verticalSpacer_17;
    QWidget *page_reinhard05;
    QGridLayout *gridLayout_15;
    QGridLayout *gridLayout_5;
    QSlider *brightnessSlider;
    QSlider *chromaticAdaptSlider;
    QLabel *label_saturation;
    QSlider *lightAdaptSlider;
    QLabel *label_saturation_2;
    QLabel *label_brightness;
    QDoubleSpinBox *brightnessdsb;
    QDoubleSpinBox *chromaticAdaptdsb;
    QDoubleSpinBox *lightAdaptdsb;
    QSpacerItem *verticalSpacer_18;
    QWidget *page_ashikhmin;
    QGridLayout *gridLayout_17;
    QGridLayout *gridLayout_20;
    QLabel *label_locatcontrasttreshold;
    QSlider *contrastSlider;
    QDoubleSpinBox *contrastdsb;
    QCheckBox *simpleCheckBox;
    QLabel *label_2;
    QVBoxLayout *verticalLayout_2;
    QRadioButton *eq2RadioButton;
    QRadioButton *eq4RadioButton;
    QSpacerItem *verticalSpacer_10;
    QSpacerItem *verticalSpacer_19;
    QWidget *page_pattanaik;
    QGridLayout *gridLayout_19;
    QGridLayout *gridLayout_23;
    QCheckBox *pattalocal;
    QDoubleSpinBox *multiplierdsb;
    QLabel *label_21;
    QSlider *multiplierSlider;
    QCheckBox *autoYcheckbox;
    QSlider *coneSlider;
    QLabel *label_cone;
    QDoubleSpinBox *conedsb;
    QLabel *label_rod;
    QSlider *rodSlider;
    QDoubleSpinBox *roddsb;
    QSpacerItem *verticalSpacer_2;
    QWidget *page_mai;
    QGridLayout *gridLayout_26;
    QSpacerItem *verticalSpacer_14;
    QSpacerItem *horizontalSpacer_4;
    QLabel *label_9;
    QSpacerItem *horizontalSpacer_5;
    QSpacerItem *verticalSpacer_13;
    QWidget *page_ferwerda;
    QGridLayout *gridLayout_27;
    QGridLayout *gridLayout_30;
    QSlider *ferwerdaMultiplierSlider;
    QDoubleSpinBox *ferwerdaMultiplierDsb;
    QLabel *label_brightness_2;
    QLabel *label_saturation_3;
    QDoubleSpinBox *adaptationLuminanceDsb;
    QSlider *adaptationLuminanceSlider;
    QSpacerItem *verticalSpacer_7;
    QWidget *page_kimkautz;
    QGridLayout *gridLayout_31;
    QGridLayout *gridLayout_32;
    QLabel *label_saturation_5;
    QSlider *kimkautzC1Slider;
    QDoubleSpinBox *kimkautzC1Dsb;
    QLabel *label_saturation_6;
    QSlider *kimkautzC2Slider;
    QDoubleSpinBox *kimkautzC2Dsb;
    QSpacerItem *verticalSpacer_15;
    QWidget *page_vanhateren;
    QGridLayout *gridLayout_34;
    QGridLayout *gridLayout_33;
    QSlider *pupil_areaSlider;
    QDoubleSpinBox *pupil_areaDsb;
    QLabel *pupil_area_label;
    QSpacerItem *verticalSpacer_9;
    QWidget *page_lischinski;
    QGridLayout *gridLayout_35;
    QGridLayout *gridLayout_36;
    QLabel *label_lischinski_alpha;
    QSlider *lischinski_alpha_Slider;
    QDoubleSpinBox *lischinski_alpha_Dsb;
    QSpacerItem *verticalSpacer_11;
    QHBoxLayout *horizontalLayout_undo;
    QToolButton *defaultButton;
    QSpacerItem *horizontalSpacer_2;
    QToolButton *undoButton;
    QToolButton *redoButton;
    QHBoxLayout *horizontalLayout_38;
    QPushButton *applyButton;
    QCheckBox *replaceLdrCheckBox;
    QCheckBox *autoLevelsCheckBox;
    QToolButton *toolButtonThreshold;
    QToolBox *processingToolBox;
    QWidget *page;
    QGridLayout *gridLayout_4;
    QGroupBox *pregammaGroup;
    QGridLayout *gridLayout_3;
    QLabel *label;
    QComboBox *sizeComboBox;
    QToolButton *addCustomSizeButton;
    QLabel *pregammaLabel;
    QSlider *pregammaSlider;
    QToolButton *pregammadefault;
    QDoubleSpinBox *pregammadsb;
    QLabel *label_10;
    QSlider *postsaturationSlider;
    QToolButton *postsaturationdefault;
    QDoubleSpinBox *postsaturationdsb;
    QLabel *label_12;
    QSlider *postgammaSlider;
    QToolButton *postgammadefault;
    QDoubleSpinBox *postgammadsb;
    QWidget *page_2;
    QGridLayout *gridLayout_29;
    QVBoxLayout *verticalLayout_3;
    QGroupBox *groupSaveLoadTMOsetting;
    QGridLayout *gridLayout_24;
    QGridLayout *gridLayout_25;
    QToolButton *savesettingsbutton;
    QToolButton *loadsettingsbutton;
    QSpacerItem *horizontalSpacer_6;
    QToolButton *loadButton;
    QToolButton *saveButton;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *horizontalSpacer_7;
    QGroupBox *groupBoxExport;
    QGridLayout *gridLayout_28;
    QHBoxLayout *horizontalLayout_2;
    QToolButton *queueButton;
    QLabel *lblOpenQueue;
    QHBoxLayout *frameSpinner;
    QSpacerItem *horizontalSpacer_3;
    QLabel *lblQueueSize;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *TonemappingPanel)
    {
        if (TonemappingPanel->objectName().isEmpty())
            TonemappingPanel->setObjectName(QString::fromUtf8("TonemappingPanel"));
        TonemappingPanel->setEnabled(true);
        TonemappingPanel->resize(421, 647);
        QSizePolicy sizePolicy(QSizePolicy::Minimum, QSizePolicy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(TonemappingPanel->sizePolicy().hasHeightForWidth());
        TonemappingPanel->setSizePolicy(sizePolicy);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/icons/luminance-hdr.png"), QSize(), QIcon::Normal, QIcon::Off);
        TonemappingPanel->setWindowIcon(icon);
        gridLayout_13 = new QGridLayout(TonemappingPanel);
        gridLayout_13->setObjectName(QString::fromUtf8("gridLayout_13"));
        line = new QFrame(TonemappingPanel);
        line->setObjectName(QString::fromUtf8("line"));
        line->setFrameShape(QFrame::HLine);
        line->setFrameShadow(QFrame::Sunken);

        gridLayout_13->addWidget(line, 2, 0, 1, 1);

        tonemapGroupBox = new QGroupBox(TonemappingPanel);
        tonemapGroupBox->setObjectName(QString::fromUtf8("tonemapGroupBox"));
        tonemapGroupBox->setEnabled(true);
        QSizePolicy sizePolicy1(QSizePolicy::Minimum, QSizePolicy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(tonemapGroupBox->sizePolicy().hasHeightForWidth());
        tonemapGroupBox->setSizePolicy(sizePolicy1);
        verticalLayout = new QVBoxLayout(tonemapGroupBox);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        verticalLayout->setContentsMargins(4, 4, 4, 4);
        gridLayout_operator = new QGridLayout();
        gridLayout_operator->setObjectName(QString::fromUtf8("gridLayout_operator"));
        cmbOperators = new QComboBox(tonemapGroupBox);
        cmbOperators->addItem(QString());
        cmbOperators->addItem(QString());
        cmbOperators->addItem(QString());
        cmbOperators->addItem(QString());
        cmbOperators->addItem(QString());
        cmbOperators->addItem(QString());
        cmbOperators->addItem(QString());
        cmbOperators->addItem(QString());
        cmbOperators->addItem(QString());
        cmbOperators->addItem(QString());
        cmbOperators->addItem(QString());
        cmbOperators->addItem(QString());
        cmbOperators->addItem(QString());
        cmbOperators->addItem(QString());
        cmbOperators->addItem(QString());
        cmbOperators->setObjectName(QString::fromUtf8("cmbOperators"));
        QSizePolicy sizePolicy2(QSizePolicy::MinimumExpanding, QSizePolicy::Minimum);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(cmbOperators->sizePolicy().hasHeightForWidth());
        cmbOperators->setSizePolicy(sizePolicy2);
        cmbOperators->setFrame(true);

        gridLayout_operator->addWidget(cmbOperators, 0, 1, 1, 1);

        lblOperators = new QLabel(tonemapGroupBox);
        lblOperators->setObjectName(QString::fromUtf8("lblOperators"));
        sizePolicy1.setHeightForWidth(lblOperators->sizePolicy().hasHeightForWidth());
        lblOperators->setSizePolicy(sizePolicy1);
        lblOperators->setMinimumSize(QSize(0, 0));
        lblOperators->setMaximumSize(QSize(16777215, 16777215));
        lblOperators->setTextFormat(Qt::RichText);
        lblOperators->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_operator->addWidget(lblOperators, 0, 0, 1, 1);


        verticalLayout->addLayout(gridLayout_operator);

        stackedWidget_operators = new QStackedWidget(tonemapGroupBox);
        stackedWidget_operators->setObjectName(QString::fromUtf8("stackedWidget_operators"));
        sizePolicy2.setHeightForWidth(stackedWidget_operators->sizePolicy().hasHeightForWidth());
        stackedWidget_operators->setSizePolicy(sizePolicy2);
        stackedWidget_operators->setMinimumSize(QSize(0, 0));
        stackedWidget_operators->setFrameShape(QFrame::NoFrame);
        stackedWidget_operators->setFrameShadow(QFrame::Plain);
        page_mantiuk06 = new QWidget();
        page_mantiuk06->setObjectName(QString::fromUtf8("page_mantiuk06"));
        sizePolicy1.setHeightForWidth(page_mantiuk06->sizePolicy().hasHeightForWidth());
        page_mantiuk06->setSizePolicy(sizePolicy1);
        gridLayout_6 = new QGridLayout(page_mantiuk06);
        gridLayout_6->setObjectName(QString::fromUtf8("gridLayout_6"));
        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName(QString::fromUtf8("gridLayout_2"));
        label_23 = new QLabel(page_mantiuk06);
        label_23->setObjectName(QString::fromUtf8("label_23"));
        sizePolicy1.setHeightForWidth(label_23->sizePolicy().hasHeightForWidth());
        label_23->setSizePolicy(sizePolicy1);
        label_23->setLayoutDirection(Qt::LeftToRight);
        label_23->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_23->setWordWrap(true);

        gridLayout_2->addWidget(label_23, 0, 0, 1, 1);

        contrastEqualizCheckBox = new QCheckBox(page_mantiuk06);
        contrastEqualizCheckBox->setObjectName(QString::fromUtf8("contrastEqualizCheckBox"));
        sizePolicy2.setHeightForWidth(contrastEqualizCheckBox->sizePolicy().hasHeightForWidth());
        contrastEqualizCheckBox->setSizePolicy(sizePolicy2);

        gridLayout_2->addWidget(contrastEqualizCheckBox, 3, 1, 1, 1);

        detailFactorSlider = new QSlider(page_mantiuk06);
        detailFactorSlider->setObjectName(QString::fromUtf8("detailFactorSlider"));
        detailFactorSlider->setEnabled(true);
        sizePolicy2.setHeightForWidth(detailFactorSlider->sizePolicy().hasHeightForWidth());
        detailFactorSlider->setSizePolicy(sizePolicy2);
        detailFactorSlider->setCursor(QCursor(Qt::PointingHandCursor));
        detailFactorSlider->setMaximum(1000);
        detailFactorSlider->setOrientation(Qt::Horizontal);

        gridLayout_2->addWidget(detailFactorSlider, 2, 1, 1, 1);

        contrastFactorSlider = new QSlider(page_mantiuk06);
        contrastFactorSlider->setObjectName(QString::fromUtf8("contrastFactorSlider"));
        sizePolicy2.setHeightForWidth(contrastFactorSlider->sizePolicy().hasHeightForWidth());
        contrastFactorSlider->setSizePolicy(sizePolicy2);
        contrastFactorSlider->setCursor(QCursor(Qt::PointingHandCursor));
        contrastFactorSlider->setMinimum(0);
        contrastFactorSlider->setMaximum(1000);
        contrastFactorSlider->setOrientation(Qt::Horizontal);

        gridLayout_2->addWidget(contrastFactorSlider, 0, 1, 1, 1);

        label_desc_df = new QLabel(page_mantiuk06);
        label_desc_df->setObjectName(QString::fromUtf8("label_desc_df"));
        label_desc_df->setEnabled(true);
        sizePolicy1.setHeightForWidth(label_desc_df->sizePolicy().hasHeightForWidth());
        label_desc_df->setSizePolicy(sizePolicy1);
        label_desc_df->setLayoutDirection(Qt::LeftToRight);
        label_desc_df->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_desc_df->setWordWrap(true);

        gridLayout_2->addWidget(label_desc_df, 2, 0, 1, 1);

        label_22 = new QLabel(page_mantiuk06);
        label_22->setObjectName(QString::fromUtf8("label_22"));
        sizePolicy1.setHeightForWidth(label_22->sizePolicy().hasHeightForWidth());
        label_22->setSizePolicy(sizePolicy1);
        label_22->setLayoutDirection(Qt::LeftToRight);
        label_22->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_22->setWordWrap(true);

        gridLayout_2->addWidget(label_22, 1, 0, 1, 1);

        saturationFactorSlider = new QSlider(page_mantiuk06);
        saturationFactorSlider->setObjectName(QString::fromUtf8("saturationFactorSlider"));
        sizePolicy2.setHeightForWidth(saturationFactorSlider->sizePolicy().hasHeightForWidth());
        saturationFactorSlider->setSizePolicy(sizePolicy2);
        saturationFactorSlider->setCursor(QCursor(Qt::PointingHandCursor));
        saturationFactorSlider->setMaximum(1000);
        saturationFactorSlider->setOrientation(Qt::Horizontal);

        gridLayout_2->addWidget(saturationFactorSlider, 1, 1, 1, 1);

        contrastFactordsb = new QDoubleSpinBox(page_mantiuk06);
        contrastFactordsb->setObjectName(QString::fromUtf8("contrastFactordsb"));
        sizePolicy1.setHeightForWidth(contrastFactordsb->sizePolicy().hasHeightForWidth());
        contrastFactordsb->setSizePolicy(sizePolicy1);
        contrastFactordsb->setAlignment(Qt::AlignCenter);
        contrastFactordsb->setButtonSymbols(QAbstractSpinBox::NoButtons);
        contrastFactordsb->setDecimals(2);
        contrastFactordsb->setMinimum(0.000000000000000);
        contrastFactordsb->setMaximum(1.000000000000000);
        contrastFactordsb->setSingleStep(0.200000000000000);
        contrastFactordsb->setValue(0.100000000000000);

        gridLayout_2->addWidget(contrastFactordsb, 0, 2, 1, 1);

        saturationFactordsb = new QDoubleSpinBox(page_mantiuk06);
        saturationFactordsb->setObjectName(QString::fromUtf8("saturationFactordsb"));
        sizePolicy1.setHeightForWidth(saturationFactordsb->sizePolicy().hasHeightForWidth());
        saturationFactordsb->setSizePolicy(sizePolicy1);
        saturationFactordsb->setAlignment(Qt::AlignCenter);
        saturationFactordsb->setButtonSymbols(QAbstractSpinBox::NoButtons);
        saturationFactordsb->setDecimals(2);
        saturationFactordsb->setMinimum(0.000000000000000);
        saturationFactordsb->setMaximum(2.000000000000000);
        saturationFactordsb->setSingleStep(0.200000000000000);
        saturationFactordsb->setValue(0.800000000000000);

        gridLayout_2->addWidget(saturationFactordsb, 1, 2, 1, 1);

        detailFactordsb = new QDoubleSpinBox(page_mantiuk06);
        detailFactordsb->setObjectName(QString::fromUtf8("detailFactordsb"));
        detailFactordsb->setEnabled(true);
        sizePolicy1.setHeightForWidth(detailFactordsb->sizePolicy().hasHeightForWidth());
        detailFactordsb->setSizePolicy(sizePolicy1);
        detailFactordsb->setAlignment(Qt::AlignCenter);
        detailFactordsb->setButtonSymbols(QAbstractSpinBox::NoButtons);
        detailFactordsb->setDecimals(1);
        detailFactordsb->setMinimum(1.000000000000000);
        detailFactordsb->setMaximum(99.000000000000000);
        detailFactordsb->setSingleStep(1.000000000000000);
        detailFactordsb->setValue(1.000000000000000);

        gridLayout_2->addWidget(detailFactordsb, 2, 2, 1, 1);


        gridLayout_6->addLayout(gridLayout_2, 0, 0, 1, 1);

        verticalSpacer_3 = new QSpacerItem(13, 56, QSizePolicy::Minimum, QSizePolicy::MinimumExpanding);

        gridLayout_6->addItem(verticalSpacer_3, 1, 0, 1, 1);

        stackedWidget_operators->addWidget(page_mantiuk06);
        page_mantiuk08 = new QWidget();
        page_mantiuk08->setObjectName(QString::fromUtf8("page_mantiuk08"));
        sizePolicy1.setHeightForWidth(page_mantiuk08->sizePolicy().hasHeightForWidth());
        page_mantiuk08->setSizePolicy(sizePolicy1);
        gridLayout_9 = new QGridLayout(page_mantiuk08);
        gridLayout_9->setObjectName(QString::fromUtf8("gridLayout_9"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        displayComboBox = new QComboBox(page_mantiuk08);
        displayComboBox->addItem(QString());
        displayComboBox->addItem(QString());
        displayComboBox->addItem(QString());
        displayComboBox->addItem(QString());
        displayComboBox->setObjectName(QString::fromUtf8("displayComboBox"));
        sizePolicy2.setHeightForWidth(displayComboBox->sizePolicy().hasHeightForWidth());
        displayComboBox->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(displayComboBox, 0, 1, 1, 1);

        label_3 = new QLabel(page_mantiuk08);
        label_3->setObjectName(QString::fromUtf8("label_3"));
        sizePolicy1.setHeightForWidth(label_3->sizePolicy().hasHeightForWidth());
        label_3->setSizePolicy(sizePolicy1);
        label_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_3->setWordWrap(true);

        gridLayout->addWidget(label_3, 1, 0, 1, 1);

        label_4 = new QLabel(page_mantiuk08);
        label_4->setObjectName(QString::fromUtf8("label_4"));
        sizePolicy1.setHeightForWidth(label_4->sizePolicy().hasHeightForWidth());
        label_4->setSizePolicy(sizePolicy1);
        label_4->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_4->setWordWrap(true);

        gridLayout->addWidget(label_4, 2, 0, 1, 1);

        luminanceLevelCheckBox = new QCheckBox(page_mantiuk08);
        luminanceLevelCheckBox->setObjectName(QString::fromUtf8("luminanceLevelCheckBox"));
        sizePolicy2.setHeightForWidth(luminanceLevelCheckBox->sizePolicy().hasHeightForWidth());
        luminanceLevelCheckBox->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(luminanceLevelCheckBox, 3, 1, 1, 1);

        label_5 = new QLabel(page_mantiuk08);
        label_5->setObjectName(QString::fromUtf8("label_5"));
        label_5->setEnabled(false);
        sizePolicy1.setHeightForWidth(label_5->sizePolicy().hasHeightForWidth());
        label_5->setSizePolicy(sizePolicy1);
        label_5->setMinimumSize(QSize(0, 0));
        label_5->setMaximumSize(QSize(16777215, 16777215));
        label_5->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_5->setWordWrap(true);

        gridLayout->addWidget(label_5, 4, 0, 1, 1);

        luminanceLevelDSB = new QDoubleSpinBox(page_mantiuk08);
        luminanceLevelDSB->setObjectName(QString::fromUtf8("luminanceLevelDSB"));
        luminanceLevelDSB->setEnabled(false);
        luminanceLevelDSB->setAlignment(Qt::AlignCenter);
        luminanceLevelDSB->setButtonSymbols(QAbstractSpinBox::NoButtons);
        luminanceLevelDSB->setMaximum(100.000000000000000);

        gridLayout->addWidget(luminanceLevelDSB, 4, 2, 1, 1);

        contrastEnhancementDSB = new QDoubleSpinBox(page_mantiuk08);
        contrastEnhancementDSB->setObjectName(QString::fromUtf8("contrastEnhancementDSB"));
        contrastEnhancementDSB->setAlignment(Qt::AlignCenter);
        contrastEnhancementDSB->setButtonSymbols(QAbstractSpinBox::NoButtons);
        contrastEnhancementDSB->setMinimum(0.010000000000000);
        contrastEnhancementDSB->setMaximum(10.000000000000000);
        contrastEnhancementDSB->setSingleStep(0.100000000000000);

        gridLayout->addWidget(contrastEnhancementDSB, 2, 2, 1, 1);

        luminanceLevelSlider = new QSlider(page_mantiuk08);
        luminanceLevelSlider->setObjectName(QString::fromUtf8("luminanceLevelSlider"));
        luminanceLevelSlider->setEnabled(false);
        sizePolicy2.setHeightForWidth(luminanceLevelSlider->sizePolicy().hasHeightForWidth());
        luminanceLevelSlider->setSizePolicy(sizePolicy2);
        luminanceLevelSlider->setMaximum(100);
        luminanceLevelSlider->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(luminanceLevelSlider, 4, 1, 1, 1);

        contrastEnhancementSlider = new QSlider(page_mantiuk08);
        contrastEnhancementSlider->setObjectName(QString::fromUtf8("contrastEnhancementSlider"));
        sizePolicy2.setHeightForWidth(contrastEnhancementSlider->sizePolicy().hasHeightForWidth());
        contrastEnhancementSlider->setSizePolicy(sizePolicy2);
        contrastEnhancementSlider->setMaximum(100);
        contrastEnhancementSlider->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(contrastEnhancementSlider, 2, 1, 1, 1);

        colorSaturationDSB = new QDoubleSpinBox(page_mantiuk08);
        colorSaturationDSB->setObjectName(QString::fromUtf8("colorSaturationDSB"));
        colorSaturationDSB->setAlignment(Qt::AlignCenter);
        colorSaturationDSB->setButtonSymbols(QAbstractSpinBox::NoButtons);
        colorSaturationDSB->setMaximum(2.000000000000000);
        colorSaturationDSB->setSingleStep(0.100000000000000);
        colorSaturationDSB->setValue(1.000000000000000);

        gridLayout->addWidget(colorSaturationDSB, 1, 2, 1, 1);

        colorSaturationSlider = new QSlider(page_mantiuk08);
        colorSaturationSlider->setObjectName(QString::fromUtf8("colorSaturationSlider"));
        sizePolicy2.setHeightForWidth(colorSaturationSlider->sizePolicy().hasHeightForWidth());
        colorSaturationSlider->setSizePolicy(sizePolicy2);
        colorSaturationSlider->setMaximum(100);
        colorSaturationSlider->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(colorSaturationSlider, 1, 1, 1, 1);

        label_6 = new QLabel(page_mantiuk08);
        label_6->setObjectName(QString::fromUtf8("label_6"));
        sizePolicy1.setHeightForWidth(label_6->sizePolicy().hasHeightForWidth());
        label_6->setSizePolicy(sizePolicy1);
        label_6->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_6->setWordWrap(true);

        gridLayout->addWidget(label_6, 0, 0, 1, 1);


        gridLayout_9->addLayout(gridLayout, 0, 0, 1, 1);

        verticalSpacer_4 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_9->addItem(verticalSpacer_4, 1, 0, 1, 1);

        stackedWidget_operators->addWidget(page_mantiuk08);
        page_fattal = new QWidget();
        page_fattal->setObjectName(QString::fromUtf8("page_fattal"));
        sizePolicy1.setHeightForWidth(page_fattal->sizePolicy().hasHeightForWidth());
        page_fattal->setSizePolicy(sizePolicy1);
        gridLayout_10 = new QGridLayout(page_fattal);
        gridLayout_10->setObjectName(QString::fromUtf8("gridLayout_10"));
        gridLayout_18 = new QGridLayout();
        gridLayout_18->setObjectName(QString::fromUtf8("gridLayout_18"));
        label_17 = new QLabel(page_fattal);
        label_17->setObjectName(QString::fromUtf8("label_17"));
        sizePolicy1.setHeightForWidth(label_17->sizePolicy().hasHeightForWidth());
        label_17->setSizePolicy(sizePolicy1);
        label_17->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_17->setWordWrap(true);

        gridLayout_18->addWidget(label_17, 0, 0, 1, 1);

        alphaSlider = new QSlider(page_fattal);
        alphaSlider->setObjectName(QString::fromUtf8("alphaSlider"));
        alphaSlider->setEnabled(true);
        sizePolicy2.setHeightForWidth(alphaSlider->sizePolicy().hasHeightForWidth());
        alphaSlider->setSizePolicy(sizePolicy2);
        alphaSlider->setCursor(QCursor(Qt::PointingHandCursor));
        alphaSlider->setMaximum(100);
        alphaSlider->setOrientation(Qt::Horizontal);

        gridLayout_18->addWidget(alphaSlider, 0, 1, 1, 1);

        alphadsb = new QDoubleSpinBox(page_fattal);
        alphadsb->setObjectName(QString::fromUtf8("alphadsb"));
        alphadsb->setEnabled(true);
        alphadsb->setAlignment(Qt::AlignCenter);
        alphadsb->setButtonSymbols(QAbstractSpinBox::NoButtons);
        alphadsb->setDecimals(2);
        alphadsb->setMinimum(0.000000000000000);
        alphadsb->setMaximum(2.000000000000000);
        alphadsb->setSingleStep(0.050000000000000);
        alphadsb->setValue(1.000000000000000);

        gridLayout_18->addWidget(alphadsb, 0, 2, 1, 1);

        label_19 = new QLabel(page_fattal);
        label_19->setObjectName(QString::fromUtf8("label_19"));
        sizePolicy1.setHeightForWidth(label_19->sizePolicy().hasHeightForWidth());
        label_19->setSizePolicy(sizePolicy1);
        label_19->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_19->setWordWrap(true);

        gridLayout_18->addWidget(label_19, 1, 0, 1, 1);

        betaSlider = new QSlider(page_fattal);
        betaSlider->setObjectName(QString::fromUtf8("betaSlider"));
        sizePolicy2.setHeightForWidth(betaSlider->sizePolicy().hasHeightForWidth());
        betaSlider->setSizePolicy(sizePolicy2);
        betaSlider->setCursor(QCursor(Qt::PointingHandCursor));
        betaSlider->setMaximum(100);
        betaSlider->setOrientation(Qt::Horizontal);

        gridLayout_18->addWidget(betaSlider, 1, 1, 1, 1);

        betadsb = new QDoubleSpinBox(page_fattal);
        betadsb->setObjectName(QString::fromUtf8("betadsb"));
        betadsb->setAlignment(Qt::AlignCenter);
        betadsb->setButtonSymbols(QAbstractSpinBox::NoButtons);
        betadsb->setDecimals(2);
        betadsb->setMinimum(0.100000000000000);
        betadsb->setMaximum(2.000000000000000);
        betadsb->setSingleStep(0.050000000000000);
        betadsb->setValue(0.900000000000000);

        gridLayout_18->addWidget(betadsb, 1, 2, 1, 1);

        saturation2dsb = new QDoubleSpinBox(page_fattal);
        saturation2dsb->setObjectName(QString::fromUtf8("saturation2dsb"));
        saturation2dsb->setAlignment(Qt::AlignCenter);
        saturation2dsb->setButtonSymbols(QAbstractSpinBox::NoButtons);
        saturation2dsb->setDecimals(2);
        saturation2dsb->setMaximum(1.500000000000000);
        saturation2dsb->setSingleStep(0.050000000000000);
        saturation2dsb->setValue(0.800000000000000);

        gridLayout_18->addWidget(saturation2dsb, 2, 2, 1, 1);

        saturation2Slider = new QSlider(page_fattal);
        saturation2Slider->setObjectName(QString::fromUtf8("saturation2Slider"));
        sizePolicy2.setHeightForWidth(saturation2Slider->sizePolicy().hasHeightForWidth());
        saturation2Slider->setSizePolicy(sizePolicy2);
        saturation2Slider->setCursor(QCursor(Qt::PointingHandCursor));
        saturation2Slider->setMaximum(100);
        saturation2Slider->setOrientation(Qt::Horizontal);

        gridLayout_18->addWidget(saturation2Slider, 2, 1, 1, 1);

        label_18 = new QLabel(page_fattal);
        label_18->setObjectName(QString::fromUtf8("label_18"));
        sizePolicy1.setHeightForWidth(label_18->sizePolicy().hasHeightForWidth());
        label_18->setSizePolicy(sizePolicy1);
        label_18->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_18->setWordWrap(true);

        gridLayout_18->addWidget(label_18, 2, 0, 1, 1);

        label_20 = new QLabel(page_fattal);
        label_20->setObjectName(QString::fromUtf8("label_20"));
        sizePolicy1.setHeightForWidth(label_20->sizePolicy().hasHeightForWidth());
        label_20->setSizePolicy(sizePolicy1);
        label_20->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_20->setWordWrap(true);

        gridLayout_18->addWidget(label_20, 3, 0, 1, 1);

        noiseSlider = new QSlider(page_fattal);
        noiseSlider->setObjectName(QString::fromUtf8("noiseSlider"));
        sizePolicy2.setHeightForWidth(noiseSlider->sizePolicy().hasHeightForWidth());
        noiseSlider->setSizePolicy(sizePolicy2);
        noiseSlider->setCursor(QCursor(Qt::PointingHandCursor));
        noiseSlider->setMaximum(100);
        noiseSlider->setOrientation(Qt::Horizontal);

        gridLayout_18->addWidget(noiseSlider, 3, 1, 1, 1);

        fftVersionCheckBox = new QCheckBox(page_fattal);
        fftVersionCheckBox->setObjectName(QString::fromUtf8("fftVersionCheckBox"));
        sizePolicy2.setHeightForWidth(fftVersionCheckBox->sizePolicy().hasHeightForWidth());
        fftVersionCheckBox->setSizePolicy(sizePolicy2);
        fftVersionCheckBox->setChecked(true);

        gridLayout_18->addWidget(fftVersionCheckBox, 4, 1, 1, 1);

        noisedsb = new QDoubleSpinBox(page_fattal);
        noisedsb->setObjectName(QString::fromUtf8("noisedsb"));
        noisedsb->setAlignment(Qt::AlignCenter);
        noisedsb->setButtonSymbols(QAbstractSpinBox::NoButtons);
        noisedsb->setDecimals(2);
        noisedsb->setMaximum(1.000000000000000);
        noisedsb->setSingleStep(0.010000000000000);
        noisedsb->setValue(0.000000000000000);

        gridLayout_18->addWidget(noisedsb, 3, 2, 1, 1);


        gridLayout_10->addLayout(gridLayout_18, 0, 0, 1, 1);

        verticalSpacer_5 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_10->addItem(verticalSpacer_5, 1, 0, 1, 1);

        stackedWidget_operators->addWidget(page_fattal);
        page_ferradans = new QWidget();
        page_ferradans->setObjectName(QString::fromUtf8("page_ferradans"));
        gridLayout_11 = new QGridLayout(page_ferradans);
        gridLayout_11->setObjectName(QString::fromUtf8("gridLayout_11"));
        gridLayout_16 = new QGridLayout();
        gridLayout_16->setObjectName(QString::fromUtf8("gridLayout_16"));
        rhoSlider = new QSlider(page_ferradans);
        rhoSlider->setObjectName(QString::fromUtf8("rhoSlider"));
        sizePolicy2.setHeightForWidth(rhoSlider->sizePolicy().hasHeightForWidth());
        rhoSlider->setSizePolicy(sizePolicy2);
        rhoSlider->setMinimum(-100);
        rhoSlider->setMaximum(100);
        rhoSlider->setValue(-40);
        rhoSlider->setOrientation(Qt::Horizontal);

        gridLayout_16->addWidget(rhoSlider, 0, 1, 1, 1);

        label_8 = new QLabel(page_ferradans);
        label_8->setObjectName(QString::fromUtf8("label_8"));
        sizePolicy1.setHeightForWidth(label_8->sizePolicy().hasHeightForWidth());
        label_8->setSizePolicy(sizePolicy1);
        label_8->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_16->addWidget(label_8, 1, 0, 1, 1);

        inv_alphaSlider = new QSlider(page_ferradans);
        inv_alphaSlider->setObjectName(QString::fromUtf8("inv_alphaSlider"));
        sizePolicy2.setHeightForWidth(inv_alphaSlider->sizePolicy().hasHeightForWidth());
        inv_alphaSlider->setSizePolicy(sizePolicy2);
        inv_alphaSlider->setOrientation(Qt::Horizontal);

        gridLayout_16->addWidget(inv_alphaSlider, 1, 1, 1, 1);

        label_7 = new QLabel(page_ferradans);
        label_7->setObjectName(QString::fromUtf8("label_7"));
        sizePolicy1.setHeightForWidth(label_7->sizePolicy().hasHeightForWidth());
        label_7->setSizePolicy(sizePolicy1);
        label_7->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_16->addWidget(label_7, 0, 0, 1, 1);

        rhodsb = new QDoubleSpinBox(page_ferradans);
        rhodsb->setObjectName(QString::fromUtf8("rhodsb"));
        rhodsb->setDecimals(2);
        rhodsb->setMinimum(-10.000000000000000);
        rhodsb->setMaximum(10.000000000000000);
        rhodsb->setSingleStep(0.100000000000000);
        rhodsb->setValue(-2.000000000000000);

        gridLayout_16->addWidget(rhodsb, 0, 2, 1, 1);

        inv_alphadsb = new QDoubleSpinBox(page_ferradans);
        inv_alphadsb->setObjectName(QString::fromUtf8("inv_alphadsb"));
        inv_alphadsb->setMaximum(10.000000000000000);
        inv_alphadsb->setSingleStep(0.100000000000000);
        inv_alphadsb->setValue(5.000000000000000);

        gridLayout_16->addWidget(inv_alphadsb, 1, 2, 1, 1);


        gridLayout_11->addLayout(gridLayout_16, 0, 0, 1, 1);

        verticalSpacer_6 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_11->addItem(verticalSpacer_6, 1, 0, 1, 1);

        stackedWidget_operators->addWidget(page_ferradans);
        page_drago = new QWidget();
        page_drago->setObjectName(QString::fromUtf8("page_drago"));
        sizePolicy1.setHeightForWidth(page_drago->sizePolicy().hasHeightForWidth());
        page_drago->setSizePolicy(sizePolicy1);
        gridLayout_21 = new QGridLayout(page_drago);
        gridLayout_21->setObjectName(QString::fromUtf8("gridLayout_21"));
        gridLayout_7 = new QGridLayout();
        gridLayout_7->setObjectName(QString::fromUtf8("gridLayout_7"));
        label_11 = new QLabel(page_drago);
        label_11->setObjectName(QString::fromUtf8("label_11"));
        sizePolicy1.setHeightForWidth(label_11->sizePolicy().hasHeightForWidth());
        label_11->setSizePolicy(sizePolicy1);
        label_11->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_11->setWordWrap(true);

        gridLayout_7->addWidget(label_11, 0, 0, 1, 1);

        biasSlider = new QSlider(page_drago);
        biasSlider->setObjectName(QString::fromUtf8("biasSlider"));
        sizePolicy2.setHeightForWidth(biasSlider->sizePolicy().hasHeightForWidth());
        biasSlider->setSizePolicy(sizePolicy2);
        biasSlider->setCursor(QCursor(Qt::PointingHandCursor));
        biasSlider->setMaximum(100);
        biasSlider->setOrientation(Qt::Horizontal);

        gridLayout_7->addWidget(biasSlider, 0, 1, 1, 1);

        biasdsb = new QDoubleSpinBox(page_drago);
        biasdsb->setObjectName(QString::fromUtf8("biasdsb"));
        biasdsb->setAlignment(Qt::AlignCenter);
        biasdsb->setButtonSymbols(QAbstractSpinBox::NoButtons);
        biasdsb->setMinimum(0.000000000000000);
        biasdsb->setMaximum(1.000000000000000);
        biasdsb->setSingleStep(0.010000000000000);
        biasdsb->setValue(0.850000000000000);

        gridLayout_7->addWidget(biasdsb, 0, 2, 1, 1);


        gridLayout_21->addLayout(gridLayout_7, 0, 0, 1, 1);

        verticalSpacer_12 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_21->addItem(verticalSpacer_12, 1, 0, 1, 1);

        stackedWidget_operators->addWidget(page_drago);
        page_durand = new QWidget();
        page_durand->setObjectName(QString::fromUtf8("page_durand"));
        sizePolicy1.setHeightForWidth(page_durand->sizePolicy().hasHeightForWidth());
        page_durand->setSizePolicy(sizePolicy1);
        gridLayout_8 = new QGridLayout(page_durand);
        gridLayout_8->setObjectName(QString::fromUtf8("gridLayout_8"));
        gridLayout_14 = new QGridLayout();
        gridLayout_14->setObjectName(QString::fromUtf8("gridLayout_14"));
        label_spatialsigma = new QLabel(page_durand);
        label_spatialsigma->setObjectName(QString::fromUtf8("label_spatialsigma"));
        sizePolicy1.setHeightForWidth(label_spatialsigma->sizePolicy().hasHeightForWidth());
        label_spatialsigma->setSizePolicy(sizePolicy1);
        label_spatialsigma->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_spatialsigma->setWordWrap(true);

        gridLayout_14->addWidget(label_spatialsigma, 1, 0, 1, 1);

        label_basecontrast = new QLabel(page_durand);
        label_basecontrast->setObjectName(QString::fromUtf8("label_basecontrast"));
        sizePolicy1.setHeightForWidth(label_basecontrast->sizePolicy().hasHeightForWidth());
        label_basecontrast->setSizePolicy(sizePolicy1);
        label_basecontrast->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_basecontrast->setWordWrap(true);

        gridLayout_14->addWidget(label_basecontrast, 0, 0, 1, 1);

        basedsb = new QDoubleSpinBox(page_durand);
        basedsb->setObjectName(QString::fromUtf8("basedsb"));
        basedsb->setAlignment(Qt::AlignCenter);
        basedsb->setButtonSymbols(QAbstractSpinBox::NoButtons);
        basedsb->setMaximum(10.000000000000000);
        basedsb->setValue(5.000000000000000);

        gridLayout_14->addWidget(basedsb, 0, 2, 1, 1);

        spatialdsb = new QDoubleSpinBox(page_durand);
        spatialdsb->setObjectName(QString::fromUtf8("spatialdsb"));
        spatialdsb->setFrame(true);
        spatialdsb->setAlignment(Qt::AlignCenter);
        spatialdsb->setButtonSymbols(QAbstractSpinBox::NoButtons);
        spatialdsb->setMaximum(100.000000000000000);
        spatialdsb->setSingleStep(1.000000000000000);
        spatialdsb->setValue(2.000000000000000);

        gridLayout_14->addWidget(spatialdsb, 1, 2, 1, 1);

        baseSlider = new QSlider(page_durand);
        baseSlider->setObjectName(QString::fromUtf8("baseSlider"));
        sizePolicy2.setHeightForWidth(baseSlider->sizePolicy().hasHeightForWidth());
        baseSlider->setSizePolicy(sizePolicy2);
        baseSlider->setCursor(QCursor(Qt::PointingHandCursor));
        baseSlider->setMaximum(100);
        baseSlider->setOrientation(Qt::Horizontal);

        gridLayout_14->addWidget(baseSlider, 0, 1, 1, 1);

        spatialSlider = new QSlider(page_durand);
        spatialSlider->setObjectName(QString::fromUtf8("spatialSlider"));
        sizePolicy2.setHeightForWidth(spatialSlider->sizePolicy().hasHeightForWidth());
        spatialSlider->setSizePolicy(sizePolicy2);
        spatialSlider->setCursor(QCursor(Qt::PointingHandCursor));
        spatialSlider->setMaximum(100);
        spatialSlider->setOrientation(Qt::Horizontal);

        gridLayout_14->addWidget(spatialSlider, 1, 1, 1, 1);

        label_rangesigma = new QLabel(page_durand);
        label_rangesigma->setObjectName(QString::fromUtf8("label_rangesigma"));
        sizePolicy1.setHeightForWidth(label_rangesigma->sizePolicy().hasHeightForWidth());
        label_rangesigma->setSizePolicy(sizePolicy1);
        label_rangesigma->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_rangesigma->setWordWrap(true);

        gridLayout_14->addWidget(label_rangesigma, 2, 0, 1, 1);

        rangeSlider = new QSlider(page_durand);
        rangeSlider->setObjectName(QString::fromUtf8("rangeSlider"));
        sizePolicy2.setHeightForWidth(rangeSlider->sizePolicy().hasHeightForWidth());
        rangeSlider->setSizePolicy(sizePolicy2);
        rangeSlider->setCursor(QCursor(Qt::PointingHandCursor));
        rangeSlider->setMaximum(100);
        rangeSlider->setOrientation(Qt::Horizontal);

        gridLayout_14->addWidget(rangeSlider, 2, 1, 1, 1);

        rangedsb = new QDoubleSpinBox(page_durand);
        rangedsb->setObjectName(QString::fromUtf8("rangedsb"));
        rangedsb->setAlignment(Qt::AlignCenter);
        rangedsb->setButtonSymbols(QAbstractSpinBox::NoButtons);
        rangedsb->setMinimum(0.010000000000000);
        rangedsb->setMaximum(10.000000000000000);
        rangedsb->setSingleStep(0.100000000000000);
        rangedsb->setValue(0.400000000000000);

        gridLayout_14->addWidget(rangedsb, 2, 2, 1, 1);


        gridLayout_8->addLayout(gridLayout_14, 0, 0, 1, 1);

        verticalSpacer_16 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_8->addItem(verticalSpacer_16, 1, 0, 1, 1);

        stackedWidget_operators->addWidget(page_durand);
        page_reinhard02 = new QWidget();
        page_reinhard02->setObjectName(QString::fromUtf8("page_reinhard02"));
        sizePolicy1.setHeightForWidth(page_reinhard02->sizePolicy().hasHeightForWidth());
        page_reinhard02->setSizePolicy(sizePolicy1);
        gridLayout_12 = new QGridLayout(page_reinhard02);
        gridLayout_12->setObjectName(QString::fromUtf8("gridLayout_12"));
        gridLayout_22 = new QGridLayout();
        gridLayout_22->setObjectName(QString::fromUtf8("gridLayout_22"));
        phiSlider = new QSlider(page_reinhard02);
        phiSlider->setObjectName(QString::fromUtf8("phiSlider"));
        sizePolicy2.setHeightForWidth(phiSlider->sizePolicy().hasHeightForWidth());
        phiSlider->setSizePolicy(sizePolicy2);
        phiSlider->setCursor(QCursor(Qt::PointingHandCursor));
        phiSlider->setMaximum(1000);
        phiSlider->setOrientation(Qt::Horizontal);

        gridLayout_22->addWidget(phiSlider, 1, 2, 1, 1);

        verticalSpacer_8 = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::MinimumExpanding);

        gridLayout_22->addItem(verticalSpacer_8, 6, 3, 1, 1);

        phidsb = new QDoubleSpinBox(page_reinhard02);
        phidsb->setObjectName(QString::fromUtf8("phidsb"));
        phidsb->setAlignment(Qt::AlignCenter);
        phidsb->setButtonSymbols(QAbstractSpinBox::NoButtons);
        phidsb->setMaximum(100.000000000000000);
        phidsb->setSingleStep(1.000000000000000);
        phidsb->setValue(1.000000000000000);

        gridLayout_22->addWidget(phidsb, 1, 4, 1, 1);

        range2dsb = new QDoubleSpinBox(page_reinhard02);
        range2dsb->setObjectName(QString::fromUtf8("range2dsb"));
        range2dsb->setEnabled(false);
        range2dsb->setAlignment(Qt::AlignCenter);
        range2dsb->setButtonSymbols(QAbstractSpinBox::NoButtons);
        range2dsb->setDecimals(0);
        range2dsb->setMinimum(1.000000000000000);
        range2dsb->setMaximum(32.000000000000000);
        range2dsb->setValue(8.000000000000000);

        gridLayout_22->addWidget(range2dsb, 3, 4, 1, 1);

        keydsb = new QDoubleSpinBox(page_reinhard02);
        keydsb->setObjectName(QString::fromUtf8("keydsb"));
        keydsb->setAlignment(Qt::AlignCenter);
        keydsb->setButtonSymbols(QAbstractSpinBox::NoButtons);
        keydsb->setMaximum(1.000000000000000);
        keydsb->setSingleStep(0.010000000000000);
        keydsb->setValue(0.180000000000000);

        gridLayout_22->addWidget(keydsb, 0, 4, 1, 1);

        lowerdsb = new QDoubleSpinBox(page_reinhard02);
        lowerdsb->setObjectName(QString::fromUtf8("lowerdsb"));
        lowerdsb->setEnabled(false);
        lowerdsb->setAlignment(Qt::AlignCenter);
        lowerdsb->setButtonSymbols(QAbstractSpinBox::NoButtons);
        lowerdsb->setDecimals(0);
        lowerdsb->setMinimum(1.000000000000000);
        lowerdsb->setMaximum(100.000000000000000);
        lowerdsb->setSingleStep(10.000000000000000);
        lowerdsb->setValue(1.000000000000000);

        gridLayout_22->addWidget(lowerdsb, 4, 4, 1, 1);

        upperdsb = new QDoubleSpinBox(page_reinhard02);
        upperdsb->setObjectName(QString::fromUtf8("upperdsb"));
        upperdsb->setEnabled(false);
        upperdsb->setAlignment(Qt::AlignCenter);
        upperdsb->setButtonSymbols(QAbstractSpinBox::NoButtons);
        upperdsb->setDecimals(0);
        upperdsb->setMinimum(1.000000000000000);
        upperdsb->setMaximum(100.000000000000000);
        upperdsb->setSingleStep(1.000000000000000);
        upperdsb->setValue(43.000000000000000);

        gridLayout_22->addWidget(upperdsb, 5, 4, 1, 1);

        range2Slider = new QSlider(page_reinhard02);
        range2Slider->setObjectName(QString::fromUtf8("range2Slider"));
        range2Slider->setEnabled(false);
        sizePolicy2.setHeightForWidth(range2Slider->sizePolicy().hasHeightForWidth());
        range2Slider->setSizePolicy(sizePolicy2);
        range2Slider->setCursor(QCursor(Qt::PointingHandCursor));
        range2Slider->setMinimum(1);
        range2Slider->setMaximum(100);
        range2Slider->setPageStep(10);
        range2Slider->setValue(1);
        range2Slider->setOrientation(Qt::Horizontal);

        gridLayout_22->addWidget(range2Slider, 3, 2, 1, 1);

        label_phi = new QLabel(page_reinhard02);
        label_phi->setObjectName(QString::fromUtf8("label_phi"));
        sizePolicy1.setHeightForWidth(label_phi->sizePolicy().hasHeightForWidth());
        label_phi->setSizePolicy(sizePolicy1);
        label_phi->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_phi->setWordWrap(true);

        gridLayout_22->addWidget(label_phi, 1, 0, 1, 1);

        label_key = new QLabel(page_reinhard02);
        label_key->setObjectName(QString::fromUtf8("label_key"));
        sizePolicy1.setHeightForWidth(label_key->sizePolicy().hasHeightForWidth());
        label_key->setSizePolicy(sizePolicy1);
        label_key->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_key->setWordWrap(true);

        gridLayout_22->addWidget(label_key, 0, 0, 1, 1);

        label_lowerscale = new QLabel(page_reinhard02);
        label_lowerscale->setObjectName(QString::fromUtf8("label_lowerscale"));
        label_lowerscale->setEnabled(false);
        sizePolicy1.setHeightForWidth(label_lowerscale->sizePolicy().hasHeightForWidth());
        label_lowerscale->setSizePolicy(sizePolicy1);
        label_lowerscale->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_22->addWidget(label_lowerscale, 4, 0, 1, 1);

        keySlider = new QSlider(page_reinhard02);
        keySlider->setObjectName(QString::fromUtf8("keySlider"));
        sizePolicy2.setHeightForWidth(keySlider->sizePolicy().hasHeightForWidth());
        keySlider->setSizePolicy(sizePolicy2);
        keySlider->setCursor(QCursor(Qt::PointingHandCursor));
        keySlider->setMaximum(100);
        keySlider->setOrientation(Qt::Horizontal);

        gridLayout_22->addWidget(keySlider, 0, 2, 1, 1);

        lowerSlider = new QSlider(page_reinhard02);
        lowerSlider->setObjectName(QString::fromUtf8("lowerSlider"));
        lowerSlider->setEnabled(false);
        sizePolicy2.setHeightForWidth(lowerSlider->sizePolicy().hasHeightForWidth());
        lowerSlider->setSizePolicy(sizePolicy2);
        lowerSlider->setCursor(QCursor(Qt::PointingHandCursor));
        lowerSlider->setMinimum(0);
        lowerSlider->setMaximum(100);
        lowerSlider->setOrientation(Qt::Horizontal);

        gridLayout_22->addWidget(lowerSlider, 4, 2, 1, 1);

        label_upperscale = new QLabel(page_reinhard02);
        label_upperscale->setObjectName(QString::fromUtf8("label_upperscale"));
        label_upperscale->setEnabled(false);
        sizePolicy1.setHeightForWidth(label_upperscale->sizePolicy().hasHeightForWidth());
        label_upperscale->setSizePolicy(sizePolicy1);
        label_upperscale->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_22->addWidget(label_upperscale, 5, 0, 1, 1);

        upperSlider = new QSlider(page_reinhard02);
        upperSlider->setObjectName(QString::fromUtf8("upperSlider"));
        upperSlider->setEnabled(false);
        sizePolicy2.setHeightForWidth(upperSlider->sizePolicy().hasHeightForWidth());
        upperSlider->setSizePolicy(sizePolicy2);
        upperSlider->setCursor(QCursor(Qt::PointingHandCursor));
        upperSlider->setMinimum(0);
        upperSlider->setMaximum(100);
        upperSlider->setOrientation(Qt::Horizontal);

        gridLayout_22->addWidget(upperSlider, 5, 2, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        usescalescheckbox = new QCheckBox(page_reinhard02);
        usescalescheckbox->setObjectName(QString::fromUtf8("usescalescheckbox"));
        sizePolicy1.setHeightForWidth(usescalescheckbox->sizePolicy().hasHeightForWidth());
        usescalescheckbox->setSizePolicy(sizePolicy1);
        usescalescheckbox->setMinimumSize(QSize(0, 28));
        usescalescheckbox->setLayoutDirection(Qt::RightToLeft);

        horizontalLayout->addWidget(usescalescheckbox);

        label_range = new QLabel(page_reinhard02);
        label_range->setObjectName(QString::fromUtf8("label_range"));
        label_range->setEnabled(false);
        sizePolicy1.setHeightForWidth(label_range->sizePolicy().hasHeightForWidth());
        label_range->setSizePolicy(sizePolicy1);
        label_range->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_range->setWordWrap(true);

        horizontalLayout->addWidget(label_range);


        gridLayout_22->addLayout(horizontalLayout, 3, 0, 1, 1);


        gridLayout_12->addLayout(gridLayout_22, 0, 0, 1, 1);

        verticalSpacer_17 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_12->addItem(verticalSpacer_17, 1, 0, 1, 1);

        stackedWidget_operators->addWidget(page_reinhard02);
        page_reinhard05 = new QWidget();
        page_reinhard05->setObjectName(QString::fromUtf8("page_reinhard05"));
        sizePolicy1.setHeightForWidth(page_reinhard05->sizePolicy().hasHeightForWidth());
        page_reinhard05->setSizePolicy(sizePolicy1);
        gridLayout_15 = new QGridLayout(page_reinhard05);
        gridLayout_15->setObjectName(QString::fromUtf8("gridLayout_15"));
        gridLayout_5 = new QGridLayout();
        gridLayout_5->setObjectName(QString::fromUtf8("gridLayout_5"));
        brightnessSlider = new QSlider(page_reinhard05);
        brightnessSlider->setObjectName(QString::fromUtf8("brightnessSlider"));
        sizePolicy2.setHeightForWidth(brightnessSlider->sizePolicy().hasHeightForWidth());
        brightnessSlider->setSizePolicy(sizePolicy2);
        brightnessSlider->setCursor(QCursor(Qt::PointingHandCursor));
        brightnessSlider->setMinimum(-100);
        brightnessSlider->setMaximum(100);
        brightnessSlider->setSingleStep(1);
        brightnessSlider->setPageStep(10);
        brightnessSlider->setOrientation(Qt::Horizontal);

        gridLayout_5->addWidget(brightnessSlider, 0, 1, 1, 1);

        chromaticAdaptSlider = new QSlider(page_reinhard05);
        chromaticAdaptSlider->setObjectName(QString::fromUtf8("chromaticAdaptSlider"));
        sizePolicy2.setHeightForWidth(chromaticAdaptSlider->sizePolicy().hasHeightForWidth());
        chromaticAdaptSlider->setSizePolicy(sizePolicy2);
        chromaticAdaptSlider->setCursor(QCursor(Qt::PointingHandCursor));
        chromaticAdaptSlider->setMaximum(100);
        chromaticAdaptSlider->setOrientation(Qt::Horizontal);

        gridLayout_5->addWidget(chromaticAdaptSlider, 1, 1, 1, 1);

        label_saturation = new QLabel(page_reinhard05);
        label_saturation->setObjectName(QString::fromUtf8("label_saturation"));
        sizePolicy1.setHeightForWidth(label_saturation->sizePolicy().hasHeightForWidth());
        label_saturation->setSizePolicy(sizePolicy1);
        label_saturation->setMinimumSize(QSize(0, 0));
        label_saturation->setMaximumSize(QSize(16777215, 16777215));
        label_saturation->setLayoutDirection(Qt::LeftToRight);
        label_saturation->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_saturation->setWordWrap(true);

        gridLayout_5->addWidget(label_saturation, 2, 0, 1, 1);

        lightAdaptSlider = new QSlider(page_reinhard05);
        lightAdaptSlider->setObjectName(QString::fromUtf8("lightAdaptSlider"));
        sizePolicy2.setHeightForWidth(lightAdaptSlider->sizePolicy().hasHeightForWidth());
        lightAdaptSlider->setSizePolicy(sizePolicy2);
        lightAdaptSlider->setCursor(QCursor(Qt::PointingHandCursor));
        lightAdaptSlider->setMaximum(100);
        lightAdaptSlider->setOrientation(Qt::Horizontal);

        gridLayout_5->addWidget(lightAdaptSlider, 2, 1, 1, 1);

        label_saturation_2 = new QLabel(page_reinhard05);
        label_saturation_2->setObjectName(QString::fromUtf8("label_saturation_2"));
        sizePolicy1.setHeightForWidth(label_saturation_2->sizePolicy().hasHeightForWidth());
        label_saturation_2->setSizePolicy(sizePolicy1);
        label_saturation_2->setMinimumSize(QSize(0, 0));
        label_saturation_2->setMaximumSize(QSize(16777215, 16777215));
        label_saturation_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_saturation_2->setWordWrap(true);

        gridLayout_5->addWidget(label_saturation_2, 1, 0, 1, 1);

        label_brightness = new QLabel(page_reinhard05);
        label_brightness->setObjectName(QString::fromUtf8("label_brightness"));
        sizePolicy1.setHeightForWidth(label_brightness->sizePolicy().hasHeightForWidth());
        label_brightness->setSizePolicy(sizePolicy1);
        label_brightness->setMinimumSize(QSize(0, 0));
        label_brightness->setMaximumSize(QSize(16777215, 16777215));
        label_brightness->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_5->addWidget(label_brightness, 0, 0, 1, 1);

        brightnessdsb = new QDoubleSpinBox(page_reinhard05);
        brightnessdsb->setObjectName(QString::fromUtf8("brightnessdsb"));
        brightnessdsb->setAlignment(Qt::AlignCenter);
        brightnessdsb->setButtonSymbols(QAbstractSpinBox::NoButtons);
        brightnessdsb->setMinimum(-20.000000000000000);
        brightnessdsb->setMaximum(20.000000000000000);
        brightnessdsb->setSingleStep(0.100000000000000);
        brightnessdsb->setValue(0.000000000000000);

        gridLayout_5->addWidget(brightnessdsb, 0, 2, 1, 1);

        chromaticAdaptdsb = new QDoubleSpinBox(page_reinhard05);
        chromaticAdaptdsb->setObjectName(QString::fromUtf8("chromaticAdaptdsb"));
        chromaticAdaptdsb->setAlignment(Qt::AlignCenter);
        chromaticAdaptdsb->setButtonSymbols(QAbstractSpinBox::NoButtons);
        chromaticAdaptdsb->setMinimum(0.000000000000000);
        chromaticAdaptdsb->setMaximum(1.000000000000000);
        chromaticAdaptdsb->setSingleStep(0.100000000000000);
        chromaticAdaptdsb->setValue(0.000000000000000);

        gridLayout_5->addWidget(chromaticAdaptdsb, 1, 2, 1, 1);

        lightAdaptdsb = new QDoubleSpinBox(page_reinhard05);
        lightAdaptdsb->setObjectName(QString::fromUtf8("lightAdaptdsb"));
        lightAdaptdsb->setAlignment(Qt::AlignCenter);
        lightAdaptdsb->setButtonSymbols(QAbstractSpinBox::NoButtons);
        lightAdaptdsb->setMinimum(0.000000000000000);
        lightAdaptdsb->setMaximum(1.000000000000000);
        lightAdaptdsb->setSingleStep(0.100000000000000);
        lightAdaptdsb->setValue(1.000000000000000);

        gridLayout_5->addWidget(lightAdaptdsb, 2, 2, 1, 1);


        gridLayout_15->addLayout(gridLayout_5, 0, 0, 1, 1);

        verticalSpacer_18 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_15->addItem(verticalSpacer_18, 1, 0, 1, 1);

        stackedWidget_operators->addWidget(page_reinhard05);
        page_ashikhmin = new QWidget();
        page_ashikhmin->setObjectName(QString::fromUtf8("page_ashikhmin"));
        page_ashikhmin->setEnabled(true);
        sizePolicy1.setHeightForWidth(page_ashikhmin->sizePolicy().hasHeightForWidth());
        page_ashikhmin->setSizePolicy(sizePolicy1);
        gridLayout_17 = new QGridLayout(page_ashikhmin);
        gridLayout_17->setObjectName(QString::fromUtf8("gridLayout_17"));
        gridLayout_20 = new QGridLayout();
        gridLayout_20->setObjectName(QString::fromUtf8("gridLayout_20"));
        label_locatcontrasttreshold = new QLabel(page_ashikhmin);
        label_locatcontrasttreshold->setObjectName(QString::fromUtf8("label_locatcontrasttreshold"));
        sizePolicy1.setHeightForWidth(label_locatcontrasttreshold->sizePolicy().hasHeightForWidth());
        label_locatcontrasttreshold->setSizePolicy(sizePolicy1);
        label_locatcontrasttreshold->setMinimumSize(QSize(0, 0));
        label_locatcontrasttreshold->setMaximumSize(QSize(16777215, 16777215));
        label_locatcontrasttreshold->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_locatcontrasttreshold->setWordWrap(true);

        gridLayout_20->addWidget(label_locatcontrasttreshold, 2, 0, 1, 1);

        contrastSlider = new QSlider(page_ashikhmin);
        contrastSlider->setObjectName(QString::fromUtf8("contrastSlider"));
        sizePolicy2.setHeightForWidth(contrastSlider->sizePolicy().hasHeightForWidth());
        contrastSlider->setSizePolicy(sizePolicy2);
        contrastSlider->setCursor(QCursor(Qt::PointingHandCursor));
        contrastSlider->setMaximum(100);
        contrastSlider->setOrientation(Qt::Horizontal);

        gridLayout_20->addWidget(contrastSlider, 2, 1, 1, 1);

        contrastdsb = new QDoubleSpinBox(page_ashikhmin);
        contrastdsb->setObjectName(QString::fromUtf8("contrastdsb"));
        contrastdsb->setFocusPolicy(Qt::StrongFocus);
        contrastdsb->setAlignment(Qt::AlignCenter);
        contrastdsb->setButtonSymbols(QAbstractSpinBox::NoButtons);
        contrastdsb->setDecimals(2);
        contrastdsb->setMaximum(1.000000000000000);
        contrastdsb->setSingleStep(0.100000000000000);
        contrastdsb->setValue(0.500000000000000);

        gridLayout_20->addWidget(contrastdsb, 2, 2, 1, 1);

        simpleCheckBox = new QCheckBox(page_ashikhmin);
        simpleCheckBox->setObjectName(QString::fromUtf8("simpleCheckBox"));
        simpleCheckBox->setEnabled(true);
        sizePolicy2.setHeightForWidth(simpleCheckBox->sizePolicy().hasHeightForWidth());
        simpleCheckBox->setSizePolicy(sizePolicy2);
        simpleCheckBox->setMinimumSize(QSize(0, 0));
        simpleCheckBox->setMaximumSize(QSize(16777215, 16777215));

        gridLayout_20->addWidget(simpleCheckBox, 0, 1, 1, 1);

        label_2 = new QLabel(page_ashikhmin);
        label_2->setObjectName(QString::fromUtf8("label_2"));
        sizePolicy1.setHeightForWidth(label_2->sizePolicy().hasHeightForWidth());
        label_2->setSizePolicy(sizePolicy1);
        label_2->setMinimumSize(QSize(0, 0));
        label_2->setMaximumSize(QSize(16777215, 16777215));
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTop|Qt::AlignTrailing);
        label_2->setWordWrap(true);

        gridLayout_20->addWidget(label_2, 1, 0, 1, 1);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        eq2RadioButton = new QRadioButton(page_ashikhmin);
        eq2RadioButton->setObjectName(QString::fromUtf8("eq2RadioButton"));
        sizePolicy2.setHeightForWidth(eq2RadioButton->sizePolicy().hasHeightForWidth());
        eq2RadioButton->setSizePolicy(sizePolicy2);
        eq2RadioButton->setChecked(true);

        verticalLayout_2->addWidget(eq2RadioButton);

        eq4RadioButton = new QRadioButton(page_ashikhmin);
        eq4RadioButton->setObjectName(QString::fromUtf8("eq4RadioButton"));
        sizePolicy2.setHeightForWidth(eq4RadioButton->sizePolicy().hasHeightForWidth());
        eq4RadioButton->setSizePolicy(sizePolicy2);

        verticalLayout_2->addWidget(eq4RadioButton);


        gridLayout_20->addLayout(verticalLayout_2, 1, 1, 1, 1);

        verticalSpacer_10 = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::MinimumExpanding);

        gridLayout_20->addItem(verticalSpacer_10, 3, 1, 1, 1);


        gridLayout_17->addLayout(gridLayout_20, 0, 0, 1, 1);

        verticalSpacer_19 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_17->addItem(verticalSpacer_19, 1, 0, 1, 1);

        stackedWidget_operators->addWidget(page_ashikhmin);
        page_pattanaik = new QWidget();
        page_pattanaik->setObjectName(QString::fromUtf8("page_pattanaik"));
        sizePolicy1.setHeightForWidth(page_pattanaik->sizePolicy().hasHeightForWidth());
        page_pattanaik->setSizePolicy(sizePolicy1);
        gridLayout_19 = new QGridLayout(page_pattanaik);
        gridLayout_19->setObjectName(QString::fromUtf8("gridLayout_19"));
        gridLayout_23 = new QGridLayout();
        gridLayout_23->setObjectName(QString::fromUtf8("gridLayout_23"));
        pattalocal = new QCheckBox(page_pattanaik);
        pattalocal->setObjectName(QString::fromUtf8("pattalocal"));
        sizePolicy2.setHeightForWidth(pattalocal->sizePolicy().hasHeightForWidth());
        pattalocal->setSizePolicy(sizePolicy2);
        pattalocal->setMinimumSize(QSize(0, 32));
        pattalocal->setMaximumSize(QSize(16777215, 32));

        gridLayout_23->addWidget(pattalocal, 1, 1, 1, 1);

        multiplierdsb = new QDoubleSpinBox(page_pattanaik);
        multiplierdsb->setObjectName(QString::fromUtf8("multiplierdsb"));
        multiplierdsb->setAlignment(Qt::AlignCenter);
        multiplierdsb->setButtonSymbols(QAbstractSpinBox::NoButtons);
        multiplierdsb->setDecimals(2);
        multiplierdsb->setMinimum(0.000000000000000);
        multiplierdsb->setMaximum(1000.000000000000000);
        multiplierdsb->setValue(1.000000000000000);

        gridLayout_23->addWidget(multiplierdsb, 0, 2, 1, 1);

        label_21 = new QLabel(page_pattanaik);
        label_21->setObjectName(QString::fromUtf8("label_21"));
        sizePolicy1.setHeightForWidth(label_21->sizePolicy().hasHeightForWidth());
        label_21->setSizePolicy(sizePolicy1);
        label_21->setMinimumSize(QSize(0, 0));
        label_21->setMaximumSize(QSize(16777215, 16777215));
        label_21->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_21->setWordWrap(true);

        gridLayout_23->addWidget(label_21, 0, 0, 1, 1);

        multiplierSlider = new QSlider(page_pattanaik);
        multiplierSlider->setObjectName(QString::fromUtf8("multiplierSlider"));
        sizePolicy2.setHeightForWidth(multiplierSlider->sizePolicy().hasHeightForWidth());
        multiplierSlider->setSizePolicy(sizePolicy2);
        multiplierSlider->setCursor(QCursor(Qt::PointingHandCursor));
        multiplierSlider->setMaximum(1000);
        multiplierSlider->setOrientation(Qt::Horizontal);

        gridLayout_23->addWidget(multiplierSlider, 0, 1, 1, 1);

        autoYcheckbox = new QCheckBox(page_pattanaik);
        autoYcheckbox->setObjectName(QString::fromUtf8("autoYcheckbox"));
        sizePolicy2.setHeightForWidth(autoYcheckbox->sizePolicy().hasHeightForWidth());
        autoYcheckbox->setSizePolicy(sizePolicy2);
        autoYcheckbox->setMinimumSize(QSize(0, 28));
        autoYcheckbox->setMaximumSize(QSize(16777215, 28));
        autoYcheckbox->setChecked(true);

        gridLayout_23->addWidget(autoYcheckbox, 2, 1, 1, 1);

        coneSlider = new QSlider(page_pattanaik);
        coneSlider->setObjectName(QString::fromUtf8("coneSlider"));
        coneSlider->setEnabled(false);
        sizePolicy2.setHeightForWidth(coneSlider->sizePolicy().hasHeightForWidth());
        coneSlider->setSizePolicy(sizePolicy2);
        coneSlider->setCursor(QCursor(Qt::PointingHandCursor));
        coneSlider->setMaximum(1000);
        coneSlider->setSingleStep(1);
        coneSlider->setPageStep(10);
        coneSlider->setOrientation(Qt::Horizontal);

        gridLayout_23->addWidget(coneSlider, 3, 1, 1, 1);

        label_cone = new QLabel(page_pattanaik);
        label_cone->setObjectName(QString::fromUtf8("label_cone"));
        label_cone->setEnabled(false);
        sizePolicy1.setHeightForWidth(label_cone->sizePolicy().hasHeightForWidth());
        label_cone->setSizePolicy(sizePolicy1);
        label_cone->setMinimumSize(QSize(0, 0));
        label_cone->setMaximumSize(QSize(16777215, 16777215));
        label_cone->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_cone->setWordWrap(true);

        gridLayout_23->addWidget(label_cone, 3, 0, 1, 1);

        conedsb = new QDoubleSpinBox(page_pattanaik);
        conedsb->setObjectName(QString::fromUtf8("conedsb"));
        conedsb->setEnabled(false);
        conedsb->setAlignment(Qt::AlignCenter);
        conedsb->setButtonSymbols(QAbstractSpinBox::NoButtons);
        conedsb->setDecimals(5);
        conedsb->setMaximum(1.000000000000000);
        conedsb->setSingleStep(0.010000000000000);
        conedsb->setValue(0.500000000000000);

        gridLayout_23->addWidget(conedsb, 3, 2, 1, 1);

        label_rod = new QLabel(page_pattanaik);
        label_rod->setObjectName(QString::fromUtf8("label_rod"));
        label_rod->setEnabled(false);
        sizePolicy1.setHeightForWidth(label_rod->sizePolicy().hasHeightForWidth());
        label_rod->setSizePolicy(sizePolicy1);
        label_rod->setMinimumSize(QSize(0, 0));
        label_rod->setMaximumSize(QSize(16777215, 16777215));
        label_rod->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_rod->setWordWrap(true);

        gridLayout_23->addWidget(label_rod, 4, 0, 1, 1);

        rodSlider = new QSlider(page_pattanaik);
        rodSlider->setObjectName(QString::fromUtf8("rodSlider"));
        rodSlider->setEnabled(false);
        sizePolicy2.setHeightForWidth(rodSlider->sizePolicy().hasHeightForWidth());
        rodSlider->setSizePolicy(sizePolicy2);
        rodSlider->setCursor(QCursor(Qt::PointingHandCursor));
        rodSlider->setMaximum(1000);
        rodSlider->setSingleStep(1);
        rodSlider->setPageStep(10);
        rodSlider->setOrientation(Qt::Horizontal);

        gridLayout_23->addWidget(rodSlider, 4, 1, 1, 1);

        roddsb = new QDoubleSpinBox(page_pattanaik);
        roddsb->setObjectName(QString::fromUtf8("roddsb"));
        roddsb->setEnabled(false);
        roddsb->setAlignment(Qt::AlignCenter);
        roddsb->setButtonSymbols(QAbstractSpinBox::NoButtons);
        roddsb->setDecimals(5);
        roddsb->setMaximum(1.000000000000000);
        roddsb->setSingleStep(0.010000000000000);
        roddsb->setValue(0.500000000000000);

        gridLayout_23->addWidget(roddsb, 4, 2, 1, 1);


        gridLayout_19->addLayout(gridLayout_23, 0, 0, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_19->addItem(verticalSpacer_2, 1, 0, 1, 1);

        stackedWidget_operators->addWidget(page_pattanaik);
        page_mai = new QWidget();
        page_mai->setObjectName(QString::fromUtf8("page_mai"));
        gridLayout_26 = new QGridLayout(page_mai);
        gridLayout_26->setObjectName(QString::fromUtf8("gridLayout_26"));
        verticalSpacer_14 = new QSpacerItem(20, 75, QSizePolicy::Minimum, QSizePolicy::MinimumExpanding);

        gridLayout_26->addItem(verticalSpacer_14, 0, 1, 1, 1);

        horizontalSpacer_4 = new QSpacerItem(98, 20, QSizePolicy::MinimumExpanding, QSizePolicy::Minimum);

        gridLayout_26->addItem(horizontalSpacer_4, 1, 0, 1, 1);

        label_9 = new QLabel(page_mai);
        label_9->setObjectName(QString::fromUtf8("label_9"));
        sizePolicy1.setHeightForWidth(label_9->sizePolicy().hasHeightForWidth());
        label_9->setSizePolicy(sizePolicy1);

        gridLayout_26->addWidget(label_9, 1, 1, 1, 1);

        horizontalSpacer_5 = new QSpacerItem(98, 20, QSizePolicy::MinimumExpanding, QSizePolicy::Minimum);

        gridLayout_26->addItem(horizontalSpacer_5, 1, 2, 1, 1);

        verticalSpacer_13 = new QSpacerItem(20, 75, QSizePolicy::Minimum, QSizePolicy::MinimumExpanding);

        gridLayout_26->addItem(verticalSpacer_13, 2, 1, 1, 1);

        stackedWidget_operators->addWidget(page_mai);
        page_ferwerda = new QWidget();
        page_ferwerda->setObjectName(QString::fromUtf8("page_ferwerda"));
        gridLayout_27 = new QGridLayout(page_ferwerda);
        gridLayout_27->setObjectName(QString::fromUtf8("gridLayout_27"));
        gridLayout_30 = new QGridLayout();
        gridLayout_30->setObjectName(QString::fromUtf8("gridLayout_30"));
        ferwerdaMultiplierSlider = new QSlider(page_ferwerda);
        ferwerdaMultiplierSlider->setObjectName(QString::fromUtf8("ferwerdaMultiplierSlider"));
        sizePolicy2.setHeightForWidth(ferwerdaMultiplierSlider->sizePolicy().hasHeightForWidth());
        ferwerdaMultiplierSlider->setSizePolicy(sizePolicy2);
        ferwerdaMultiplierSlider->setCursor(QCursor(Qt::PointingHandCursor));
        ferwerdaMultiplierSlider->setMinimum(0);
        ferwerdaMultiplierSlider->setMaximum(2000);
        ferwerdaMultiplierSlider->setSingleStep(1);
        ferwerdaMultiplierSlider->setPageStep(10);
        ferwerdaMultiplierSlider->setValue(1000);
        ferwerdaMultiplierSlider->setOrientation(Qt::Horizontal);

        gridLayout_30->addWidget(ferwerdaMultiplierSlider, 0, 1, 1, 1);

        ferwerdaMultiplierDsb = new QDoubleSpinBox(page_ferwerda);
        ferwerdaMultiplierDsb->setObjectName(QString::fromUtf8("ferwerdaMultiplierDsb"));
        ferwerdaMultiplierDsb->setAlignment(Qt::AlignCenter);
        ferwerdaMultiplierDsb->setButtonSymbols(QAbstractSpinBox::NoButtons);
        ferwerdaMultiplierDsb->setDecimals(3);
        ferwerdaMultiplierDsb->setMinimum(0.001000000000000);
        ferwerdaMultiplierDsb->setMaximum(2.000000000000000);
        ferwerdaMultiplierDsb->setSingleStep(0.100000000000000);
        ferwerdaMultiplierDsb->setValue(1.000000000000000);

        gridLayout_30->addWidget(ferwerdaMultiplierDsb, 0, 2, 1, 1);

        label_brightness_2 = new QLabel(page_ferwerda);
        label_brightness_2->setObjectName(QString::fromUtf8("label_brightness_2"));
        sizePolicy1.setHeightForWidth(label_brightness_2->sizePolicy().hasHeightForWidth());
        label_brightness_2->setSizePolicy(sizePolicy1);
        label_brightness_2->setMinimumSize(QSize(0, 0));
        label_brightness_2->setMaximumSize(QSize(16777215, 16777215));
        label_brightness_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_30->addWidget(label_brightness_2, 0, 0, 1, 1);

        label_saturation_3 = new QLabel(page_ferwerda);
        label_saturation_3->setObjectName(QString::fromUtf8("label_saturation_3"));
        sizePolicy1.setHeightForWidth(label_saturation_3->sizePolicy().hasHeightForWidth());
        label_saturation_3->setSizePolicy(sizePolicy1);
        label_saturation_3->setMinimumSize(QSize(0, 0));
        label_saturation_3->setMaximumSize(QSize(16777215, 16777215));
        label_saturation_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_saturation_3->setWordWrap(true);

        gridLayout_30->addWidget(label_saturation_3, 1, 0, 1, 1);

        adaptationLuminanceDsb = new QDoubleSpinBox(page_ferwerda);
        adaptationLuminanceDsb->setObjectName(QString::fromUtf8("adaptationLuminanceDsb"));
        adaptationLuminanceDsb->setAlignment(Qt::AlignCenter);
        adaptationLuminanceDsb->setButtonSymbols(QAbstractSpinBox::NoButtons);
        adaptationLuminanceDsb->setDecimals(3);
        adaptationLuminanceDsb->setMinimum(0.001000000000000);
        adaptationLuminanceDsb->setMaximum(1.000000000000000);
        adaptationLuminanceDsb->setSingleStep(0.100000000000000);
        adaptationLuminanceDsb->setValue(0.500000000000000);

        gridLayout_30->addWidget(adaptationLuminanceDsb, 1, 2, 1, 1);

        adaptationLuminanceSlider = new QSlider(page_ferwerda);
        adaptationLuminanceSlider->setObjectName(QString::fromUtf8("adaptationLuminanceSlider"));
        sizePolicy2.setHeightForWidth(adaptationLuminanceSlider->sizePolicy().hasHeightForWidth());
        adaptationLuminanceSlider->setSizePolicy(sizePolicy2);
        adaptationLuminanceSlider->setCursor(QCursor(Qt::PointingHandCursor));
        adaptationLuminanceSlider->setMaximum(1000);
        adaptationLuminanceSlider->setValue(500);
        adaptationLuminanceSlider->setOrientation(Qt::Horizontal);

        gridLayout_30->addWidget(adaptationLuminanceSlider, 1, 1, 1, 1);


        gridLayout_27->addLayout(gridLayout_30, 0, 0, 1, 1);

        verticalSpacer_7 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_27->addItem(verticalSpacer_7, 1, 0, 1, 1);

        stackedWidget_operators->addWidget(page_ferwerda);
        page_kimkautz = new QWidget();
        page_kimkautz->setObjectName(QString::fromUtf8("page_kimkautz"));
        gridLayout_31 = new QGridLayout(page_kimkautz);
        gridLayout_31->setObjectName(QString::fromUtf8("gridLayout_31"));
        gridLayout_32 = new QGridLayout();
        gridLayout_32->setObjectName(QString::fromUtf8("gridLayout_32"));
        label_saturation_5 = new QLabel(page_kimkautz);
        label_saturation_5->setObjectName(QString::fromUtf8("label_saturation_5"));
        sizePolicy1.setHeightForWidth(label_saturation_5->sizePolicy().hasHeightForWidth());
        label_saturation_5->setSizePolicy(sizePolicy1);
        label_saturation_5->setMinimumSize(QSize(0, 0));
        label_saturation_5->setMaximumSize(QSize(16777215, 16777215));
        label_saturation_5->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_saturation_5->setWordWrap(true);

        gridLayout_32->addWidget(label_saturation_5, 0, 0, 1, 1);

        kimkautzC1Slider = new QSlider(page_kimkautz);
        kimkautzC1Slider->setObjectName(QString::fromUtf8("kimkautzC1Slider"));
        sizePolicy2.setHeightForWidth(kimkautzC1Slider->sizePolicy().hasHeightForWidth());
        kimkautzC1Slider->setSizePolicy(sizePolicy2);
        kimkautzC1Slider->setCursor(QCursor(Qt::PointingHandCursor));
        kimkautzC1Slider->setMaximum(10000);
        kimkautzC1Slider->setValue(3000);
        kimkautzC1Slider->setOrientation(Qt::Horizontal);

        gridLayout_32->addWidget(kimkautzC1Slider, 0, 1, 1, 1);

        kimkautzC1Dsb = new QDoubleSpinBox(page_kimkautz);
        kimkautzC1Dsb->setObjectName(QString::fromUtf8("kimkautzC1Dsb"));
        kimkautzC1Dsb->setAlignment(Qt::AlignCenter);
        kimkautzC1Dsb->setButtonSymbols(QAbstractSpinBox::NoButtons);
        kimkautzC1Dsb->setDecimals(3);
        kimkautzC1Dsb->setMinimum(0.001000000000000);
        kimkautzC1Dsb->setMaximum(10.000000000000000);
        kimkautzC1Dsb->setSingleStep(0.100000000000000);
        kimkautzC1Dsb->setValue(3.000000000000000);

        gridLayout_32->addWidget(kimkautzC1Dsb, 0, 2, 1, 1);

        label_saturation_6 = new QLabel(page_kimkautz);
        label_saturation_6->setObjectName(QString::fromUtf8("label_saturation_6"));
        sizePolicy1.setHeightForWidth(label_saturation_6->sizePolicy().hasHeightForWidth());
        label_saturation_6->setSizePolicy(sizePolicy1);
        label_saturation_6->setMinimumSize(QSize(0, 0));
        label_saturation_6->setMaximumSize(QSize(16777215, 16777215));
        label_saturation_6->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_saturation_6->setWordWrap(true);

        gridLayout_32->addWidget(label_saturation_6, 1, 0, 1, 1);

        kimkautzC2Slider = new QSlider(page_kimkautz);
        kimkautzC2Slider->setObjectName(QString::fromUtf8("kimkautzC2Slider"));
        sizePolicy2.setHeightForWidth(kimkautzC2Slider->sizePolicy().hasHeightForWidth());
        kimkautzC2Slider->setSizePolicy(sizePolicy2);
        kimkautzC2Slider->setCursor(QCursor(Qt::PointingHandCursor));
        kimkautzC2Slider->setMaximum(5000);
        kimkautzC2Slider->setValue(500);
        kimkautzC2Slider->setOrientation(Qt::Horizontal);

        gridLayout_32->addWidget(kimkautzC2Slider, 1, 1, 1, 1);

        kimkautzC2Dsb = new QDoubleSpinBox(page_kimkautz);
        kimkautzC2Dsb->setObjectName(QString::fromUtf8("kimkautzC2Dsb"));
        kimkautzC2Dsb->setAlignment(Qt::AlignCenter);
        kimkautzC2Dsb->setButtonSymbols(QAbstractSpinBox::NoButtons);
        kimkautzC2Dsb->setDecimals(3);
        kimkautzC2Dsb->setMinimum(0.001000000000000);
        kimkautzC2Dsb->setMaximum(5.000000000000000);
        kimkautzC2Dsb->setSingleStep(0.100000000000000);
        kimkautzC2Dsb->setValue(0.500000000000000);

        gridLayout_32->addWidget(kimkautzC2Dsb, 1, 2, 1, 1);


        gridLayout_31->addLayout(gridLayout_32, 0, 0, 1, 1);

        verticalSpacer_15 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_31->addItem(verticalSpacer_15, 1, 0, 1, 1);

        stackedWidget_operators->addWidget(page_kimkautz);
        page_vanhateren = new QWidget();
        page_vanhateren->setObjectName(QString::fromUtf8("page_vanhateren"));
        gridLayout_34 = new QGridLayout(page_vanhateren);
        gridLayout_34->setObjectName(QString::fromUtf8("gridLayout_34"));
        gridLayout_33 = new QGridLayout();
        gridLayout_33->setObjectName(QString::fromUtf8("gridLayout_33"));
        pupil_areaSlider = new QSlider(page_vanhateren);
        pupil_areaSlider->setObjectName(QString::fromUtf8("pupil_areaSlider"));
        sizePolicy2.setHeightForWidth(pupil_areaSlider->sizePolicy().hasHeightForWidth());
        pupil_areaSlider->setSizePolicy(sizePolicy2);
        pupil_areaSlider->setMinimum(0);
        pupil_areaSlider->setMaximum(100);
        pupil_areaSlider->setValue(10);
        pupil_areaSlider->setOrientation(Qt::Horizontal);

        gridLayout_33->addWidget(pupil_areaSlider, 0, 1, 1, 1);

        pupil_areaDsb = new QDoubleSpinBox(page_vanhateren);
        pupil_areaDsb->setObjectName(QString::fromUtf8("pupil_areaDsb"));
        pupil_areaDsb->setDecimals(2);
        pupil_areaDsb->setMinimum(0.000000000000000);
        pupil_areaDsb->setMaximum(100.000000000000000);
        pupil_areaDsb->setSingleStep(0.100000000000000);
        pupil_areaDsb->setValue(10.000000000000000);

        gridLayout_33->addWidget(pupil_areaDsb, 0, 2, 1, 1);

        pupil_area_label = new QLabel(page_vanhateren);
        pupil_area_label->setObjectName(QString::fromUtf8("pupil_area_label"));
        sizePolicy1.setHeightForWidth(pupil_area_label->sizePolicy().hasHeightForWidth());
        pupil_area_label->setSizePolicy(sizePolicy1);
        pupil_area_label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_33->addWidget(pupil_area_label, 0, 0, 1, 1);


        gridLayout_34->addLayout(gridLayout_33, 0, 0, 1, 1);

        verticalSpacer_9 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_34->addItem(verticalSpacer_9, 1, 0, 1, 1);

        stackedWidget_operators->addWidget(page_vanhateren);
        page_lischinski = new QWidget();
        page_lischinski->setObjectName(QString::fromUtf8("page_lischinski"));
        gridLayout_35 = new QGridLayout(page_lischinski);
        gridLayout_35->setObjectName(QString::fromUtf8("gridLayout_35"));
        gridLayout_36 = new QGridLayout();
        gridLayout_36->setObjectName(QString::fromUtf8("gridLayout_36"));
        label_lischinski_alpha = new QLabel(page_lischinski);
        label_lischinski_alpha->setObjectName(QString::fromUtf8("label_lischinski_alpha"));
        sizePolicy1.setHeightForWidth(label_lischinski_alpha->sizePolicy().hasHeightForWidth());
        label_lischinski_alpha->setSizePolicy(sizePolicy1);
        label_lischinski_alpha->setMinimumSize(QSize(0, 0));
        label_lischinski_alpha->setMaximumSize(QSize(16777215, 16777215));
        label_lischinski_alpha->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_lischinski_alpha->setWordWrap(true);

        gridLayout_36->addWidget(label_lischinski_alpha, 0, 0, 1, 1);

        lischinski_alpha_Slider = new QSlider(page_lischinski);
        lischinski_alpha_Slider->setObjectName(QString::fromUtf8("lischinski_alpha_Slider"));
        sizePolicy2.setHeightForWidth(lischinski_alpha_Slider->sizePolicy().hasHeightForWidth());
        lischinski_alpha_Slider->setSizePolicy(sizePolicy2);
        lischinski_alpha_Slider->setCursor(QCursor(Qt::PointingHandCursor));
        lischinski_alpha_Slider->setMaximum(100);
        lischinski_alpha_Slider->setValue(10);
        lischinski_alpha_Slider->setOrientation(Qt::Horizontal);

        gridLayout_36->addWidget(lischinski_alpha_Slider, 0, 1, 1, 1);

        lischinski_alpha_Dsb = new QDoubleSpinBox(page_lischinski);
        lischinski_alpha_Dsb->setObjectName(QString::fromUtf8("lischinski_alpha_Dsb"));
        lischinski_alpha_Dsb->setAlignment(Qt::AlignCenter);
        lischinski_alpha_Dsb->setButtonSymbols(QAbstractSpinBox::NoButtons);
        lischinski_alpha_Dsb->setDecimals(2);
        lischinski_alpha_Dsb->setMinimum(0.010000000000000);
        lischinski_alpha_Dsb->setMaximum(10.000000000000000);
        lischinski_alpha_Dsb->setSingleStep(0.100000000000000);
        lischinski_alpha_Dsb->setValue(1.000000000000000);

        gridLayout_36->addWidget(lischinski_alpha_Dsb, 0, 2, 1, 1);


        gridLayout_35->addLayout(gridLayout_36, 0, 0, 1, 1);

        verticalSpacer_11 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_35->addItem(verticalSpacer_11, 1, 0, 1, 1);

        stackedWidget_operators->addWidget(page_lischinski);

        verticalLayout->addWidget(stackedWidget_operators);

        horizontalLayout_undo = new QHBoxLayout();
        horizontalLayout_undo->setObjectName(QString::fromUtf8("horizontalLayout_undo"));
        defaultButton = new QToolButton(tonemapGroupBox);
        defaultButton->setObjectName(QString::fromUtf8("defaultButton"));
        sizePolicy1.setHeightForWidth(defaultButton->sizePolicy().hasHeightForWidth());
        defaultButton->setSizePolicy(sizePolicy1);
        QIcon icon1;
        QString iconThemeName = QString::fromUtf8("edit-undo");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QString::fromUtf8("../../../../../.designer/backup"), QSize(), QIcon::Normal, QIcon::Off);
        }
        defaultButton->setIcon(icon1);
        defaultButton->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);

        horizontalLayout_undo->addWidget(defaultButton);

        horizontalSpacer_2 = new QSpacerItem(0, 20, QSizePolicy::MinimumExpanding, QSizePolicy::Minimum);

        horizontalLayout_undo->addItem(horizontalSpacer_2);

        undoButton = new QToolButton(tonemapGroupBox);
        undoButton->setObjectName(QString::fromUtf8("undoButton"));
        undoButton->setEnabled(false);
        sizePolicy1.setHeightForWidth(undoButton->sizePolicy().hasHeightForWidth());
        undoButton->setSizePolicy(sizePolicy1);
        QIcon icon2;
        iconThemeName = QString::fromUtf8("go-previous");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon2 = QIcon::fromTheme(iconThemeName);
        } else {
            icon2.addFile(QString::fromUtf8("../../../../../.designer/backup"), QSize(), QIcon::Normal, QIcon::Off);
        }
        undoButton->setIcon(icon2);
        undoButton->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);

        horizontalLayout_undo->addWidget(undoButton);

        redoButton = new QToolButton(tonemapGroupBox);
        redoButton->setObjectName(QString::fromUtf8("redoButton"));
        redoButton->setEnabled(false);
        sizePolicy1.setHeightForWidth(redoButton->sizePolicy().hasHeightForWidth());
        redoButton->setSizePolicy(sizePolicy1);
        QIcon icon3;
        iconThemeName = QString::fromUtf8("go-next");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon3 = QIcon::fromTheme(iconThemeName);
        } else {
            icon3.addFile(QString::fromUtf8("../../../../../.designer/backup"), QSize(), QIcon::Normal, QIcon::Off);
        }
        redoButton->setIcon(icon3);
        redoButton->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);

        horizontalLayout_undo->addWidget(redoButton);


        verticalLayout->addLayout(horizontalLayout_undo);


        gridLayout_13->addWidget(tonemapGroupBox, 0, 0, 1, 1);

        horizontalLayout_38 = new QHBoxLayout();
        horizontalLayout_38->setObjectName(QString::fromUtf8("horizontalLayout_38"));
        applyButton = new QPushButton(TonemappingPanel);
        applyButton->setObjectName(QString::fromUtf8("applyButton"));
        sizePolicy1.setHeightForWidth(applyButton->sizePolicy().hasHeightForWidth());
        applyButton->setSizePolicy(sizePolicy1);

        horizontalLayout_38->addWidget(applyButton);

        replaceLdrCheckBox = new QCheckBox(TonemappingPanel);
        replaceLdrCheckBox->setObjectName(QString::fromUtf8("replaceLdrCheckBox"));
        sizePolicy1.setHeightForWidth(replaceLdrCheckBox->sizePolicy().hasHeightForWidth());
        replaceLdrCheckBox->setSizePolicy(sizePolicy1);
        replaceLdrCheckBox->setLayoutDirection(Qt::RightToLeft);
        replaceLdrCheckBox->setCheckable(true);
        replaceLdrCheckBox->setChecked(true);

        horizontalLayout_38->addWidget(replaceLdrCheckBox);

        autoLevelsCheckBox = new QCheckBox(TonemappingPanel);
        autoLevelsCheckBox->setObjectName(QString::fromUtf8("autoLevelsCheckBox"));
        sizePolicy1.setHeightForWidth(autoLevelsCheckBox->sizePolicy().hasHeightForWidth());
        autoLevelsCheckBox->setSizePolicy(sizePolicy1);
        autoLevelsCheckBox->setLayoutDirection(Qt::RightToLeft);
        autoLevelsCheckBox->setChecked(true);

        horizontalLayout_38->addWidget(autoLevelsCheckBox);

        toolButtonThreshold = new QToolButton(TonemappingPanel);
        toolButtonThreshold->setObjectName(QString::fromUtf8("toolButtonThreshold"));
        toolButtonThreshold->setEnabled(true);
        toolButtonThreshold->setText(QString::fromUtf8("..."));
        toolButtonThreshold->setToolButtonStyle(Qt::ToolButtonIconOnly);
        toolButtonThreshold->setArrowType(Qt::DownArrow);

        horizontalLayout_38->addWidget(toolButtonThreshold);


        gridLayout_13->addLayout(horizontalLayout_38, 3, 0, 1, 1);

        processingToolBox = new QToolBox(TonemappingPanel);
        processingToolBox->setObjectName(QString::fromUtf8("processingToolBox"));
        processingToolBox->setEnabled(true);
        sizePolicy1.setHeightForWidth(processingToolBox->sizePolicy().hasHeightForWidth());
        processingToolBox->setSizePolicy(sizePolicy1);
        page = new QWidget();
        page->setObjectName(QString::fromUtf8("page"));
        page->setGeometry(QRect(0, 0, 409, 174));
        gridLayout_4 = new QGridLayout(page);
        gridLayout_4->setObjectName(QString::fromUtf8("gridLayout_4"));
        pregammaGroup = new QGroupBox(page);
        pregammaGroup->setObjectName(QString::fromUtf8("pregammaGroup"));
        sizePolicy2.setHeightForWidth(pregammaGroup->sizePolicy().hasHeightForWidth());
        pregammaGroup->setSizePolicy(sizePolicy2);
        gridLayout_3 = new QGridLayout(pregammaGroup);
        gridLayout_3->setObjectName(QString::fromUtf8("gridLayout_3"));
        label = new QLabel(pregammaGroup);
        label->setObjectName(QString::fromUtf8("label"));
        sizePolicy1.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy1);
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label->setWordWrap(true);
        label->setMargin(1);

        gridLayout_3->addWidget(label, 0, 0, 1, 1);

        sizeComboBox = new QComboBox(pregammaGroup);
        sizeComboBox->setObjectName(QString::fromUtf8("sizeComboBox"));

        gridLayout_3->addWidget(sizeComboBox, 0, 1, 1, 1);

        addCustomSizeButton = new QToolButton(pregammaGroup);
        addCustomSizeButton->setObjectName(QString::fromUtf8("addCustomSizeButton"));
        sizePolicy1.setHeightForWidth(addCustomSizeButton->sizePolicy().hasHeightForWidth());
        addCustomSizeButton->setSizePolicy(sizePolicy1);
        addCustomSizeButton->setMinimumSize(QSize(31, 0));
        addCustomSizeButton->setMaximumSize(QSize(16777215, 16777215));
        addCustomSizeButton->setSizeIncrement(QSize(0, 0));
        addCustomSizeButton->setCursor(QCursor(Qt::PointingHandCursor));
        addCustomSizeButton->setLayoutDirection(Qt::LeftToRight);
        QIcon icon4;
        iconThemeName = QString::fromUtf8("list-add");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon4 = QIcon::fromTheme(iconThemeName);
        } else {
            icon4.addFile(QString::fromUtf8("../../../../../.designer/backup"), QSize(), QIcon::Normal, QIcon::Off);
        }
        addCustomSizeButton->setIcon(icon4);
        addCustomSizeButton->setIconSize(QSize(10, 10));

        gridLayout_3->addWidget(addCustomSizeButton, 0, 2, 1, 1);

        pregammaLabel = new QLabel(pregammaGroup);
        pregammaLabel->setObjectName(QString::fromUtf8("pregammaLabel"));
        sizePolicy1.setHeightForWidth(pregammaLabel->sizePolicy().hasHeightForWidth());
        pregammaLabel->setSizePolicy(sizePolicy1);
        pregammaLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        pregammaLabel->setMargin(1);
        pregammaLabel->setIndent(-1);

        gridLayout_3->addWidget(pregammaLabel, 1, 0, 1, 1);

        pregammaSlider = new QSlider(pregammaGroup);
        pregammaSlider->setObjectName(QString::fromUtf8("pregammaSlider"));
        pregammaSlider->setMaximum(100);
        pregammaSlider->setPageStep(1);
        pregammaSlider->setValue(10);
        pregammaSlider->setOrientation(Qt::Horizontal);

        gridLayout_3->addWidget(pregammaSlider, 1, 1, 1, 1);

        pregammadefault = new QToolButton(pregammaGroup);
        pregammadefault->setObjectName(QString::fromUtf8("pregammadefault"));
        sizePolicy1.setHeightForWidth(pregammadefault->sizePolicy().hasHeightForWidth());
        pregammadefault->setSizePolicy(sizePolicy1);
        pregammadefault->setMinimumSize(QSize(31, 0));
        pregammadefault->setMaximumSize(QSize(16777215, 16777215));
        pregammadefault->setIcon(icon1);
        pregammadefault->setIconSize(QSize(10, 10));

        gridLayout_3->addWidget(pregammadefault, 1, 2, 1, 1);

        pregammadsb = new QDoubleSpinBox(pregammaGroup);
        pregammadsb->setObjectName(QString::fromUtf8("pregammadsb"));
        pregammadsb->setAlignment(Qt::AlignCenter);
        pregammadsb->setButtonSymbols(QAbstractSpinBox::NoButtons);
        pregammadsb->setDecimals(2);
        pregammadsb->setMinimum(0.100000000000000);
        pregammadsb->setMaximum(5.000000000000000);
        pregammadsb->setSingleStep(0.100000000000000);
        pregammadsb->setValue(1.000000000000000);

        gridLayout_3->addWidget(pregammadsb, 1, 3, 1, 1);

        label_10 = new QLabel(pregammaGroup);
        label_10->setObjectName(QString::fromUtf8("label_10"));
        label_10->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_3->addWidget(label_10, 2, 0, 1, 1);

        postsaturationSlider = new QSlider(pregammaGroup);
        postsaturationSlider->setObjectName(QString::fromUtf8("postsaturationSlider"));
        postsaturationSlider->setMaximum(100);
        postsaturationSlider->setPageStep(1);
        postsaturationSlider->setValue(10);
        postsaturationSlider->setOrientation(Qt::Horizontal);

        gridLayout_3->addWidget(postsaturationSlider, 2, 1, 1, 1);

        postsaturationdefault = new QToolButton(pregammaGroup);
        postsaturationdefault->setObjectName(QString::fromUtf8("postsaturationdefault"));
        sizePolicy1.setHeightForWidth(postsaturationdefault->sizePolicy().hasHeightForWidth());
        postsaturationdefault->setSizePolicy(sizePolicy1);
        postsaturationdefault->setMinimumSize(QSize(31, 0));
        postsaturationdefault->setMaximumSize(QSize(16777215, 16777215));
        postsaturationdefault->setText(QString::fromUtf8(""));
        postsaturationdefault->setIcon(icon1);
        postsaturationdefault->setIconSize(QSize(10, 10));

        gridLayout_3->addWidget(postsaturationdefault, 2, 2, 1, 1);

        postsaturationdsb = new QDoubleSpinBox(pregammaGroup);
        postsaturationdsb->setObjectName(QString::fromUtf8("postsaturationdsb"));
        postsaturationdsb->setAlignment(Qt::AlignCenter);
        postsaturationdsb->setButtonSymbols(QAbstractSpinBox::NoButtons);
        postsaturationdsb->setMaximum(5.000000000000000);
        postsaturationdsb->setSingleStep(0.100000000000000);
        postsaturationdsb->setValue(1.000000000000000);

        gridLayout_3->addWidget(postsaturationdsb, 2, 3, 1, 1);

        label_12 = new QLabel(pregammaGroup);
        label_12->setObjectName(QString::fromUtf8("label_12"));
        label_12->setLayoutDirection(Qt::LeftToRight);
        label_12->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_3->addWidget(label_12, 3, 0, 1, 1);

        postgammaSlider = new QSlider(pregammaGroup);
        postgammaSlider->setObjectName(QString::fromUtf8("postgammaSlider"));
        postgammaSlider->setMaximum(100);
        postgammaSlider->setPageStep(1);
        postgammaSlider->setValue(10);
        postgammaSlider->setOrientation(Qt::Horizontal);

        gridLayout_3->addWidget(postgammaSlider, 3, 1, 1, 1);

        postgammadefault = new QToolButton(pregammaGroup);
        postgammadefault->setObjectName(QString::fromUtf8("postgammadefault"));
        postgammadefault->setMinimumSize(QSize(31, 0));
        QIcon icon5;
        iconThemeName = QString::fromUtf8("edit-undo");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon5 = QIcon::fromTheme(iconThemeName);
        } else {
            icon5.addFile(QString::fromUtf8("../../../../../../../.."), QSize(), QIcon::Normal, QIcon::Off);
        }
        postgammadefault->setIcon(icon5);
        postgammadefault->setIconSize(QSize(10, 10));

        gridLayout_3->addWidget(postgammadefault, 3, 2, 1, 1);

        postgammadsb = new QDoubleSpinBox(pregammaGroup);
        postgammadsb->setObjectName(QString::fromUtf8("postgammadsb"));
        postgammadsb->setAlignment(Qt::AlignCenter);
        postgammadsb->setButtonSymbols(QAbstractSpinBox::NoButtons);
        postgammadsb->setMaximum(5.000000000000000);
        postgammadsb->setSingleStep(0.100000000000000);
        postgammadsb->setValue(1.000000000000000);

        gridLayout_3->addWidget(postgammadsb, 3, 3, 1, 1);


        gridLayout_4->addWidget(pregammaGroup, 0, 0, 1, 1);

        processingToolBox->addItem(page, QString::fromUtf8("Processing"));
        page_2 = new QWidget();
        page_2->setObjectName(QString::fromUtf8("page_2"));
        page_2->setGeometry(QRect(0, 0, 409, 208));
        gridLayout_29 = new QGridLayout(page_2);
        gridLayout_29->setObjectName(QString::fromUtf8("gridLayout_29"));
        verticalLayout_3 = new QVBoxLayout();
        verticalLayout_3->setObjectName(QString::fromUtf8("verticalLayout_3"));
        groupSaveLoadTMOsetting = new QGroupBox(page_2);
        groupSaveLoadTMOsetting->setObjectName(QString::fromUtf8("groupSaveLoadTMOsetting"));
        sizePolicy1.setHeightForWidth(groupSaveLoadTMOsetting->sizePolicy().hasHeightForWidth());
        groupSaveLoadTMOsetting->setSizePolicy(sizePolicy1);
        gridLayout_24 = new QGridLayout(groupSaveLoadTMOsetting);
        gridLayout_24->setObjectName(QString::fromUtf8("gridLayout_24"));
        gridLayout_24->setContentsMargins(4, 4, 4, 4);
        gridLayout_25 = new QGridLayout();
        gridLayout_25->setObjectName(QString::fromUtf8("gridLayout_25"));
        savesettingsbutton = new QToolButton(groupSaveLoadTMOsetting);
        savesettingsbutton->setObjectName(QString::fromUtf8("savesettingsbutton"));
        sizePolicy1.setHeightForWidth(savesettingsbutton->sizePolicy().hasHeightForWidth());
        savesettingsbutton->setSizePolicy(sizePolicy1);
        savesettingsbutton->setMaximumSize(QSize(16777215, 33));
        QIcon icon6;
        iconThemeName = QString::fromUtf8("document-save");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon6 = QIcon::fromTheme(iconThemeName);
        } else {
            icon6.addFile(QString::fromUtf8("../../../../../.designer/backup"), QSize(), QIcon::Normal, QIcon::Off);
        }
        savesettingsbutton->setIcon(icon6);

        gridLayout_25->addWidget(savesettingsbutton, 0, 1, 1, 1);

        loadsettingsbutton = new QToolButton(groupSaveLoadTMOsetting);
        loadsettingsbutton->setObjectName(QString::fromUtf8("loadsettingsbutton"));
        sizePolicy1.setHeightForWidth(loadsettingsbutton->sizePolicy().hasHeightForWidth());
        loadsettingsbutton->setSizePolicy(sizePolicy1);
        loadsettingsbutton->setMaximumSize(QSize(16777215, 33));
        QIcon icon7;
        iconThemeName = QString::fromUtf8("document-open");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon7 = QIcon::fromTheme(iconThemeName);
        } else {
            icon7.addFile(QString::fromUtf8("../../../../../.designer/backup"), QSize(), QIcon::Normal, QIcon::Off);
        }
        loadsettingsbutton->setIcon(icon7);

        gridLayout_25->addWidget(loadsettingsbutton, 0, 2, 1, 1);

        horizontalSpacer_6 = new QSpacerItem(0, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_25->addItem(horizontalSpacer_6, 0, 0, 1, 1);

        loadButton = new QToolButton(groupSaveLoadTMOsetting);
        loadButton->setObjectName(QString::fromUtf8("loadButton"));
        sizePolicy1.setHeightForWidth(loadButton->sizePolicy().hasHeightForWidth());
        loadButton->setSizePolicy(sizePolicy1);
        loadButton->setMinimumSize(QSize(0, 0));
        loadButton->setMaximumSize(QSize(16777215, 33));
        QIcon icon8;
        iconThemeName = QString::fromUtf8("cloud-upload");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon8 = QIcon::fromTheme(iconThemeName);
        } else {
            icon8.addFile(QString::fromUtf8("../../../../../.designer/backup"), QSize(), QIcon::Normal, QIcon::Off);
        }
        loadButton->setIcon(icon8);

        gridLayout_25->addWidget(loadButton, 0, 5, 1, 1);

        saveButton = new QToolButton(groupSaveLoadTMOsetting);
        saveButton->setObjectName(QString::fromUtf8("saveButton"));
        sizePolicy1.setHeightForWidth(saveButton->sizePolicy().hasHeightForWidth());
        saveButton->setSizePolicy(sizePolicy1);
        saveButton->setMaximumSize(QSize(16777215, 33));
        QIcon icon9;
        iconThemeName = QString::fromUtf8("edit-download");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon9 = QIcon::fromTheme(iconThemeName);
        } else {
            icon9.addFile(QString::fromUtf8("../../../../../.designer/backup"), QSize(), QIcon::Normal, QIcon::Off);
        }
        saveButton->setIcon(icon9);

        gridLayout_25->addWidget(saveButton, 0, 4, 1, 1);

        horizontalSpacer = new QSpacerItem(0, 20, QSizePolicy::MinimumExpanding, QSizePolicy::Minimum);

        gridLayout_25->addItem(horizontalSpacer, 0, 3, 1, 1);

        horizontalSpacer_7 = new QSpacerItem(0, 20, QSizePolicy::MinimumExpanding, QSizePolicy::Minimum);

        gridLayout_25->addItem(horizontalSpacer_7, 0, 6, 1, 1);


        gridLayout_24->addLayout(gridLayout_25, 0, 0, 1, 1);


        verticalLayout_3->addWidget(groupSaveLoadTMOsetting);

        groupBoxExport = new QGroupBox(page_2);
        groupBoxExport->setObjectName(QString::fromUtf8("groupBoxExport"));
        sizePolicy1.setHeightForWidth(groupBoxExport->sizePolicy().hasHeightForWidth());
        groupBoxExport->setSizePolicy(sizePolicy1);
        gridLayout_28 = new QGridLayout(groupBoxExport);
        gridLayout_28->setObjectName(QString::fromUtf8("gridLayout_28"));
        gridLayout_28->setVerticalSpacing(6);
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        queueButton = new QToolButton(groupBoxExport);
        queueButton->setObjectName(QString::fromUtf8("queueButton"));
        sizePolicy1.setHeightForWidth(queueButton->sizePolicy().hasHeightForWidth());
        queueButton->setSizePolicy(sizePolicy1);
        queueButton->setMaximumSize(QSize(16777215, 33));
        QIcon icon10;
        iconThemeName = QString::fromUtf8("folder-pictures");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon10 = QIcon::fromTheme(iconThemeName);
        } else {
            icon10.addFile(QString::fromUtf8("../../../../../.designer/backup"), QSize(), QIcon::Normal, QIcon::Off);
        }
        queueButton->setIcon(icon10);
        queueButton->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);

        horizontalLayout_2->addWidget(queueButton);

        lblOpenQueue = new QLabel(groupBoxExport);
        lblOpenQueue->setObjectName(QString::fromUtf8("lblOpenQueue"));
        sizePolicy2.setHeightForWidth(lblOpenQueue->sizePolicy().hasHeightForWidth());
        lblOpenQueue->setSizePolicy(sizePolicy2);
        lblOpenQueue->setOpenExternalLinks(false);
        lblOpenQueue->setTextInteractionFlags(Qt::LinksAccessibleByMouse);

        horizontalLayout_2->addWidget(lblOpenQueue);

        frameSpinner = new QHBoxLayout();
        frameSpinner->setSpacing(0);
        frameSpinner->setObjectName(QString::fromUtf8("frameSpinner"));

        horizontalLayout_2->addLayout(frameSpinner);

        horizontalSpacer_3 = new QSpacerItem(0, 20, QSizePolicy::MinimumExpanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_3);


        gridLayout_28->addLayout(horizontalLayout_2, 0, 0, 1, 1);

        lblQueueSize = new QLabel(groupBoxExport);
        lblQueueSize->setObjectName(QString::fromUtf8("lblQueueSize"));
        lblQueueSize->setText(QString::fromUtf8(""));

        gridLayout_28->addWidget(lblQueueSize, 0, 1, 1, 1);


        verticalLayout_3->addWidget(groupBoxExport);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_3->addItem(verticalSpacer);


        gridLayout_29->addLayout(verticalLayout_3, 0, 0, 1, 1);

        processingToolBox->addItem(page_2, QString::fromUtf8("Settings"));

        gridLayout_13->addWidget(processingToolBox, 1, 0, 1, 1);

#if QT_CONFIG(shortcut)
        label_23->setBuddy(contrastFactorSlider);
        label_desc_df->setBuddy(detailFactorSlider);
        label_22->setBuddy(saturationFactorSlider);
        label_3->setBuddy(colorSaturationSlider);
        label_4->setBuddy(contrastEnhancementSlider);
        label_5->setBuddy(luminanceLevelSlider);
        label_6->setBuddy(displayComboBox);
        label_17->setBuddy(alphaSlider);
        label_19->setBuddy(betaSlider);
        label_18->setBuddy(saturation2Slider);
        label_20->setBuddy(noiseSlider);
        label_8->setBuddy(inv_alphaSlider);
        label_7->setBuddy(rhoSlider);
        label_11->setBuddy(biasSlider);
        label_spatialsigma->setBuddy(spatialSlider);
        label_basecontrast->setBuddy(baseSlider);
        label_rangesigma->setBuddy(rangeSlider);
        label_phi->setBuddy(phiSlider);
        label_key->setBuddy(keySlider);
        label_lowerscale->setBuddy(lowerSlider);
        label_upperscale->setBuddy(upperSlider);
        label_range->setBuddy(range2Slider);
        label_saturation->setBuddy(lightAdaptSlider);
        label_saturation_2->setBuddy(chromaticAdaptSlider);
        label_brightness->setBuddy(brightnessSlider);
        label_locatcontrasttreshold->setBuddy(contrastSlider);
        label_2->setBuddy(eq2RadioButton);
        label_21->setBuddy(multiplierSlider);
        label_cone->setBuddy(coneSlider);
        label_rod->setBuddy(rodSlider);
        label_brightness_2->setBuddy(brightnessSlider);
        label_saturation_3->setBuddy(chromaticAdaptSlider);
        label_saturation_5->setBuddy(chromaticAdaptSlider);
        label_saturation_6->setBuddy(chromaticAdaptSlider);
        pupil_area_label->setBuddy(rhoSlider);
        label_lischinski_alpha->setBuddy(chromaticAdaptSlider);
        label->setBuddy(sizeComboBox);
        pregammaLabel->setBuddy(pregammaSlider);
        label_10->setBuddy(postsaturationSlider);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(applyButton, replaceLdrCheckBox);
        QWidget::setTabOrder(replaceLdrCheckBox, autoLevelsCheckBox);
        QWidget::setTabOrder(autoLevelsCheckBox, toolButtonThreshold);
        QWidget::setTabOrder(toolButtonThreshold, sizeComboBox);
        QWidget::setTabOrder(sizeComboBox, addCustomSizeButton);
        QWidget::setTabOrder(addCustomSizeButton, pregammaSlider);
        QWidget::setTabOrder(pregammaSlider, pregammadefault);
        QWidget::setTabOrder(pregammadefault, pregammadsb);
        QWidget::setTabOrder(pregammadsb, postsaturationSlider);
        QWidget::setTabOrder(postsaturationSlider, postsaturationdefault);
        QWidget::setTabOrder(postsaturationdefault, postsaturationdsb);
        QWidget::setTabOrder(postsaturationdsb, postgammaSlider);
        QWidget::setTabOrder(postgammaSlider, postgammadefault);
        QWidget::setTabOrder(postgammadefault, postgammadsb);
        QWidget::setTabOrder(postgammadsb, savesettingsbutton);
        QWidget::setTabOrder(savesettingsbutton, loadsettingsbutton);
        QWidget::setTabOrder(loadsettingsbutton, saveButton);
        QWidget::setTabOrder(saveButton, loadButton);
        QWidget::setTabOrder(loadButton, queueButton);
        QWidget::setTabOrder(queueButton, defaultButton);
        QWidget::setTabOrder(defaultButton, undoButton);
        QWidget::setTabOrder(undoButton, redoButton);
        QWidget::setTabOrder(redoButton, cmbOperators);
        QWidget::setTabOrder(cmbOperators, contrastFactorSlider);
        QWidget::setTabOrder(contrastFactorSlider, contrastFactordsb);
        QWidget::setTabOrder(contrastFactordsb, saturationFactorSlider);
        QWidget::setTabOrder(saturationFactorSlider, saturationFactordsb);
        QWidget::setTabOrder(saturationFactordsb, detailFactorSlider);
        QWidget::setTabOrder(detailFactorSlider, detailFactordsb);
        QWidget::setTabOrder(detailFactordsb, contrastEqualizCheckBox);
        QWidget::setTabOrder(contrastEqualizCheckBox, displayComboBox);
        QWidget::setTabOrder(displayComboBox, colorSaturationSlider);
        QWidget::setTabOrder(colorSaturationSlider, colorSaturationDSB);
        QWidget::setTabOrder(colorSaturationDSB, contrastEnhancementSlider);
        QWidget::setTabOrder(contrastEnhancementSlider, contrastEnhancementDSB);
        QWidget::setTabOrder(contrastEnhancementDSB, luminanceLevelCheckBox);
        QWidget::setTabOrder(luminanceLevelCheckBox, luminanceLevelSlider);
        QWidget::setTabOrder(luminanceLevelSlider, luminanceLevelDSB);
        QWidget::setTabOrder(luminanceLevelDSB, alphaSlider);
        QWidget::setTabOrder(alphaSlider, alphadsb);
        QWidget::setTabOrder(alphadsb, betaSlider);
        QWidget::setTabOrder(betaSlider, betadsb);
        QWidget::setTabOrder(betadsb, saturation2Slider);
        QWidget::setTabOrder(saturation2Slider, saturation2dsb);
        QWidget::setTabOrder(saturation2dsb, noiseSlider);
        QWidget::setTabOrder(noiseSlider, noisedsb);
        QWidget::setTabOrder(noisedsb, fftVersionCheckBox);
        QWidget::setTabOrder(fftVersionCheckBox, rhoSlider);
        QWidget::setTabOrder(rhoSlider, rhodsb);
        QWidget::setTabOrder(rhodsb, inv_alphaSlider);
        QWidget::setTabOrder(inv_alphaSlider, inv_alphadsb);
        QWidget::setTabOrder(inv_alphadsb, biasSlider);
        QWidget::setTabOrder(biasSlider, biasdsb);
        QWidget::setTabOrder(biasdsb, baseSlider);
        QWidget::setTabOrder(baseSlider, basedsb);
        QWidget::setTabOrder(basedsb, spatialSlider);
        QWidget::setTabOrder(spatialSlider, spatialdsb);
        QWidget::setTabOrder(spatialdsb, rangeSlider);
        QWidget::setTabOrder(rangeSlider, rangedsb);
        QWidget::setTabOrder(rangedsb, keySlider);
        QWidget::setTabOrder(keySlider, keydsb);
        QWidget::setTabOrder(keydsb, phiSlider);
        QWidget::setTabOrder(phiSlider, phidsb);
        QWidget::setTabOrder(phidsb, usescalescheckbox);
        QWidget::setTabOrder(usescalescheckbox, range2Slider);
        QWidget::setTabOrder(range2Slider, range2dsb);
        QWidget::setTabOrder(range2dsb, lowerSlider);
        QWidget::setTabOrder(lowerSlider, lowerdsb);
        QWidget::setTabOrder(lowerdsb, upperSlider);
        QWidget::setTabOrder(upperSlider, upperdsb);
        QWidget::setTabOrder(upperdsb, brightnessSlider);
        QWidget::setTabOrder(brightnessSlider, brightnessdsb);
        QWidget::setTabOrder(brightnessdsb, chromaticAdaptSlider);
        QWidget::setTabOrder(chromaticAdaptSlider, chromaticAdaptdsb);
        QWidget::setTabOrder(chromaticAdaptdsb, lightAdaptSlider);
        QWidget::setTabOrder(lightAdaptSlider, lightAdaptdsb);
        QWidget::setTabOrder(lightAdaptdsb, simpleCheckBox);
        QWidget::setTabOrder(simpleCheckBox, eq2RadioButton);
        QWidget::setTabOrder(eq2RadioButton, eq4RadioButton);
        QWidget::setTabOrder(eq4RadioButton, contrastSlider);
        QWidget::setTabOrder(contrastSlider, contrastdsb);
        QWidget::setTabOrder(contrastdsb, multiplierSlider);
        QWidget::setTabOrder(multiplierSlider, multiplierdsb);
        QWidget::setTabOrder(multiplierdsb, pattalocal);
        QWidget::setTabOrder(pattalocal, autoYcheckbox);
        QWidget::setTabOrder(autoYcheckbox, coneSlider);
        QWidget::setTabOrder(coneSlider, conedsb);
        QWidget::setTabOrder(conedsb, rodSlider);
        QWidget::setTabOrder(rodSlider, roddsb);
        QWidget::setTabOrder(roddsb, ferwerdaMultiplierSlider);
        QWidget::setTabOrder(ferwerdaMultiplierSlider, ferwerdaMultiplierDsb);
        QWidget::setTabOrder(ferwerdaMultiplierDsb, adaptationLuminanceSlider);
        QWidget::setTabOrder(adaptationLuminanceSlider, adaptationLuminanceDsb);
        QWidget::setTabOrder(adaptationLuminanceDsb, kimkautzC1Slider);
        QWidget::setTabOrder(kimkautzC1Slider, kimkautzC1Dsb);
        QWidget::setTabOrder(kimkautzC1Dsb, kimkautzC2Slider);
        QWidget::setTabOrder(kimkautzC2Slider, kimkautzC2Dsb);
        QWidget::setTabOrder(kimkautzC2Dsb, pupil_areaSlider);
        QWidget::setTabOrder(pupil_areaSlider, pupil_areaDsb);
        QWidget::setTabOrder(pupil_areaDsb, lischinski_alpha_Slider);
        QWidget::setTabOrder(lischinski_alpha_Slider, lischinski_alpha_Dsb);

        retranslateUi(TonemappingPanel);
        QObject::connect(cmbOperators, SIGNAL(currentIndexChanged(int)), stackedWidget_operators, SLOT(setCurrentIndex(int)));
        QObject::connect(luminanceLevelCheckBox, SIGNAL(toggled(bool)), luminanceLevelSlider, SLOT(setEnabled(bool)));
        QObject::connect(luminanceLevelCheckBox, SIGNAL(toggled(bool)), luminanceLevelDSB, SLOT(setEnabled(bool)));
        QObject::connect(usescalescheckbox, SIGNAL(toggled(bool)), label_range, SLOT(setEnabled(bool)));
        QObject::connect(usescalescheckbox, SIGNAL(toggled(bool)), range2Slider, SLOT(setEnabled(bool)));
        QObject::connect(usescalescheckbox, SIGNAL(toggled(bool)), range2dsb, SLOT(setEnabled(bool)));
        QObject::connect(usescalescheckbox, SIGNAL(toggled(bool)), label_lowerscale, SLOT(setEnabled(bool)));
        QObject::connect(usescalescheckbox, SIGNAL(toggled(bool)), lowerSlider, SLOT(setEnabled(bool)));
        QObject::connect(usescalescheckbox, SIGNAL(toggled(bool)), lowerdsb, SLOT(setEnabled(bool)));
        QObject::connect(usescalescheckbox, SIGNAL(toggled(bool)), label_upperscale, SLOT(setEnabled(bool)));
        QObject::connect(usescalescheckbox, SIGNAL(toggled(bool)), upperSlider, SLOT(setEnabled(bool)));
        QObject::connect(usescalescheckbox, SIGNAL(toggled(bool)), upperdsb, SLOT(setEnabled(bool)));
        QObject::connect(autoYcheckbox, SIGNAL(toggled(bool)), coneSlider, SLOT(setDisabled(bool)));
        QObject::connect(autoYcheckbox, SIGNAL(toggled(bool)), conedsb, SLOT(setDisabled(bool)));
        QObject::connect(autoYcheckbox, SIGNAL(toggled(bool)), rodSlider, SLOT(setDisabled(bool)));
        QObject::connect(autoYcheckbox, SIGNAL(toggled(bool)), roddsb, SLOT(setDisabled(bool)));
        QObject::connect(luminanceLevelCheckBox, SIGNAL(toggled(bool)), label_5, SLOT(setEnabled(bool)));
        QObject::connect(simpleCheckBox, SIGNAL(toggled(bool)), label_2, SLOT(setDisabled(bool)));
        QObject::connect(simpleCheckBox, SIGNAL(toggled(bool)), eq2RadioButton, SLOT(setDisabled(bool)));
        QObject::connect(simpleCheckBox, SIGNAL(toggled(bool)), eq4RadioButton, SLOT(setDisabled(bool)));
        QObject::connect(simpleCheckBox, SIGNAL(toggled(bool)), label_locatcontrasttreshold, SLOT(setDisabled(bool)));
        QObject::connect(simpleCheckBox, SIGNAL(toggled(bool)), contrastSlider, SLOT(setDisabled(bool)));
        QObject::connect(simpleCheckBox, SIGNAL(toggled(bool)), contrastdsb, SLOT(setDisabled(bool)));
        QObject::connect(autoYcheckbox, SIGNAL(toggled(bool)), label_cone, SLOT(setDisabled(bool)));
        QObject::connect(autoYcheckbox, SIGNAL(toggled(bool)), label_rod, SLOT(setDisabled(bool)));
        QObject::connect(pattalocal, SIGNAL(toggled(bool)), autoYcheckbox, SLOT(setDisabled(bool)));
        QObject::connect(pattalocal, SIGNAL(toggled(bool)), label_cone, SLOT(setDisabled(bool)));
        QObject::connect(pattalocal, SIGNAL(toggled(bool)), coneSlider, SLOT(setDisabled(bool)));
        QObject::connect(pattalocal, SIGNAL(toggled(bool)), conedsb, SLOT(setDisabled(bool)));
        QObject::connect(pattalocal, SIGNAL(toggled(bool)), label_rod, SLOT(setDisabled(bool)));
        QObject::connect(pattalocal, SIGNAL(toggled(bool)), rodSlider, SLOT(setDisabled(bool)));
        QObject::connect(pattalocal, SIGNAL(toggled(bool)), roddsb, SLOT(setDisabled(bool)));

        cmbOperators->setCurrentIndex(0);
        stackedWidget_operators->setCurrentIndex(0);
        processingToolBox->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(TonemappingPanel);
    } // setupUi

    void retranslateUi(QWidget *TonemappingPanel)
    {
        tonemapGroupBox->setTitle(QCoreApplication::translate("TonemappingPanel", "Tonemap", nullptr));
        cmbOperators->setItemText(0, QCoreApplication::translate("TonemappingPanel", "Mantiuk '06", nullptr));
        cmbOperators->setItemText(1, QCoreApplication::translate("TonemappingPanel", "Mantiuk '08", nullptr));
        cmbOperators->setItemText(2, QCoreApplication::translate("TonemappingPanel", "Fattal", nullptr));
        cmbOperators->setItemText(3, QCoreApplication::translate("TonemappingPanel", "Ferradans", nullptr));
        cmbOperators->setItemText(4, QCoreApplication::translate("TonemappingPanel", "Drago", nullptr));
        cmbOperators->setItemText(5, QCoreApplication::translate("TonemappingPanel", "Durand", nullptr));
        cmbOperators->setItemText(6, QCoreApplication::translate("TonemappingPanel", "Reinhard '02", nullptr));
        cmbOperators->setItemText(7, QCoreApplication::translate("TonemappingPanel", "Reinhard '05", nullptr));
        cmbOperators->setItemText(8, QCoreApplication::translate("TonemappingPanel", "Ashikhmin", nullptr));
        cmbOperators->setItemText(9, QCoreApplication::translate("TonemappingPanel", "Pattanaik", nullptr));
        cmbOperators->setItemText(10, QCoreApplication::translate("TonemappingPanel", "Mai", nullptr));
        cmbOperators->setItemText(11, QCoreApplication::translate("TonemappingPanel", "Ferwerda", nullptr));
        cmbOperators->setItemText(12, QCoreApplication::translate("TonemappingPanel", "KimKautz", nullptr));
        cmbOperators->setItemText(13, QCoreApplication::translate("TonemappingPanel", "VanHateren", nullptr));
        cmbOperators->setItemText(14, QCoreApplication::translate("TonemappingPanel", "Lischinski", nullptr));

        lblOperators->setText(QCoreApplication::translate("TonemappingPanel", "Operator", nullptr));
        label_23->setText(QCoreApplication::translate("TonemappingPanel", "&Contrast Factor", nullptr));
        contrastEqualizCheckBox->setText(QCoreApplication::translate("TonemappingPanel", "Contrast Equalization", nullptr));
        label_desc_df->setText(QCoreApplication::translate("TonemappingPanel", "&Detail Factor", nullptr));
        label_22->setText(QCoreApplication::translate("TonemappingPanel", "Saturat&ion Factor", nullptr));
        displayComboBox->setItemText(0, QCoreApplication::translate("TonemappingPanel", "Lcd Office", nullptr));
        displayComboBox->setItemText(1, QCoreApplication::translate("TonemappingPanel", "Lcd", nullptr));
        displayComboBox->setItemText(2, QCoreApplication::translate("TonemappingPanel", "Lcd Bright", nullptr));
        displayComboBox->setItemText(3, QCoreApplication::translate("TonemappingPanel", "CRT", nullptr));

        label_3->setText(QCoreApplication::translate("TonemappingPanel", "Co&lor Saturation", nullptr));
        label_4->setText(QCoreApplication::translate("TonemappingPanel", "Co&ntrast Enhancement", nullptr));
        luminanceLevelCheckBox->setText(QCoreApplication::translate("TonemappingPanel", "Enable\n"
"Luminace Level", nullptr));
        label_5->setText(QCoreApplication::translate("TonemappingPanel", "Lum&inance Level", nullptr));
        label_6->setText(QCoreApplication::translate("TonemappingPanel", "Predefined &Display", nullptr));
        label_17->setText(QCoreApplication::translate("TonemappingPanel", "A&lpha", nullptr));
        label_19->setText(QCoreApplication::translate("TonemappingPanel", "Bet&a", nullptr));
        label_18->setText(QCoreApplication::translate("TonemappingPanel", "Color Saturat&ion", nullptr));
        label_20->setText(QCoreApplication::translate("TonemappingPanel", "&Noise Reduction", nullptr));
        fftVersionCheckBox->setText(QCoreApplication::translate("TonemappingPanel", "Version 2.3.0", nullptr));
        label_8->setText(QCoreApplication::translate("TonemappingPanel", "&Inverse Alpha", nullptr));
        label_7->setText(QCoreApplication::translate("TonemappingPanel", "Rho", nullptr));
        label_11->setText(QCoreApplication::translate("TonemappingPanel", "B&ias", nullptr));
        label_spatialsigma->setText(QCoreApplication::translate("TonemappingPanel", "Spatial &Kernel Sigma", nullptr));
        label_basecontrast->setText(QCoreApplication::translate("TonemappingPanel", "Base Co&ntrast", nullptr));
        label_rangesigma->setText(QCoreApplication::translate("TonemappingPanel", "Range Kerne&l Sigma", nullptr));
        label_phi->setText(QCoreApplication::translate("TonemappingPanel", "Ph&i", nullptr));
        label_key->setText(QCoreApplication::translate("TonemappingPanel", "&Key Value", nullptr));
        label_lowerscale->setText(QCoreApplication::translate("TonemappingPanel", "&Lower Scale", nullptr));
        label_upperscale->setText(QCoreApplication::translate("TonemappingPanel", "Upper S&cale", nullptr));
        usescalescheckbox->setText(QCoreApplication::translate("TonemappingPanel", "Use Scales", nullptr));
        label_range->setText(QCoreApplication::translate("TonemappingPanel", "           Ra&nge", nullptr));
        label_saturation->setText(QCoreApplication::translate("TonemappingPanel", "&Light Adaptation", nullptr));
        label_saturation_2->setText(QCoreApplication::translate("TonemappingPanel", "Chromatic A&daptation", nullptr));
        label_brightness->setText(QCoreApplication::translate("TonemappingPanel", "Br&ightness", nullptr));
        label_locatcontrasttreshold->setText(QCoreApplication::translate("TonemappingPanel", "Local Contrast Threshol&d", nullptr));
        simpleCheckBox->setText(QCoreApplication::translate("TonemappingPanel", "Simple", nullptr));
        label_2->setText(QCoreApplication::translate("TonemappingPanel", "Equation &Number", nullptr));
        eq2RadioButton->setText(QCoreApplication::translate("TonemappingPanel", "Eqn &2", nullptr));
        eq4RadioButton->setText(QCoreApplication::translate("TonemappingPanel", "Eqn &4", nullptr));
        pattalocal->setText(QCoreApplication::translate("TonemappingPanel", "Local Tone Mapping", nullptr));
        label_21->setText(QCoreApplication::translate("TonemappingPanel", "Mu&ltiplier", nullptr));
        autoYcheckbox->setText(QCoreApplication::translate("TonemappingPanel", "Auto Cone/Rod", nullptr));
        label_cone->setText(QCoreApplication::translate("TonemappingPanel", "Co&ne Level", nullptr));
        label_rod->setText(QCoreApplication::translate("TonemappingPanel", "Ro&d Level", nullptr));
        label_9->setText(QCoreApplication::translate("TonemappingPanel", "This operator has no options", nullptr));
        label_brightness_2->setText(QCoreApplication::translate("TonemappingPanel", "&Multiplier", nullptr));
        label_saturation_3->setText(QCoreApplication::translate("TonemappingPanel", "A&daptation Luminance", nullptr));
        label_saturation_5->setText(QCoreApplication::translate("TonemappingPanel", "&C1", nullptr));
        label_saturation_6->setText(QCoreApplication::translate("TonemappingPanel", "C&2", nullptr));
        pupil_area_label->setText(QCoreApplication::translate("TonemappingPanel", "Pup&il Area", nullptr));
        label_lischinski_alpha->setText(QCoreApplication::translate("TonemappingPanel", "a&lpha mul", nullptr));
#if QT_CONFIG(tooltip)
        defaultButton->setToolTip(QCoreApplication::translate("TonemappingPanel", "Restore operator's default values", nullptr));
#endif // QT_CONFIG(tooltip)
        defaultButton->setText(QCoreApplication::translate("TonemappingPanel", "Restore", nullptr));
#if QT_CONFIG(tooltip)
        undoButton->setToolTip(QCoreApplication::translate("TonemappingPanel", "Previous applied settings", nullptr));
#endif // QT_CONFIG(tooltip)
        undoButton->setText(QCoreApplication::translate("TonemappingPanel", "Previous", nullptr));
#if QT_CONFIG(tooltip)
        redoButton->setToolTip(QCoreApplication::translate("TonemappingPanel", "Next applied settings", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        redoButton->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        redoButton->setText(QCoreApplication::translate("TonemappingPanel", "Next", nullptr));
#if QT_CONFIG(tooltip)
        applyButton->setToolTip(QCoreApplication::translate("TonemappingPanel", "Start tonemapping (CTRL+T)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        applyButton->setWhatsThis(QCoreApplication::translate("TonemappingPanel", "Use current parameters above (pregamma and tone mapping operator) to compute an LDR image", nullptr));
#endif // QT_CONFIG(whatsthis)
        applyButton->setText(QCoreApplication::translate("TonemappingPanel", "&Update preview", nullptr));
#if QT_CONFIG(shortcut)
        applyButton->setShortcut(QCoreApplication::translate("TonemappingPanel", "Ctrl+T", nullptr));
#endif // QT_CONFIG(shortcut)
        replaceLdrCheckBox->setText(QCoreApplication::translate("TonemappingPanel", "Update current LDR", nullptr));
        autoLevelsCheckBox->setText(QCoreApplication::translate("TonemappingPanel", "Auto Levels", nullptr));
#if QT_CONFIG(tooltip)
        toolButtonThreshold->setToolTip(QCoreApplication::translate("TonemappingPanel", "<html><head/><body><p>set auto levels threshold</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        pregammaGroup->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        pregammaGroup->setWhatsThis(QCoreApplication::translate("TonemappingPanel", "Here you can apply a gamma correction to the HDR.<br>The gamma correction will applied before tone mapping.", nullptr));
#endif // QT_CONFIG(whatsthis)
        pregammaGroup->setTitle(QString());
        label->setText(QCoreApplication::translate("TonemappingPanel", "Res&ult Size", nullptr));
#if QT_CONFIG(tooltip)
        addCustomSizeButton->setToolTip(QCoreApplication::translate("TonemappingPanel", "Set Custom Output Size", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        addCustomSizeButton->setWhatsThis(QCoreApplication::translate("TonemappingPanel", "Clicking this button you will be able to insert a <i>width</i> value for the size of the resulting LDR image.<br>After pressing Enter (or Return) a height value will be automatically computed and the new size added to the list.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        pregammaLabel->setToolTip(QCoreApplication::translate("TonemappingPanel", "Gamma applied before tonemapping", nullptr));
#endif // QT_CONFIG(tooltip)
        pregammaLabel->setText(QCoreApplication::translate("TonemappingPanel", "Pre-&gamma", nullptr));
#if QT_CONFIG(tooltip)
        pregammadefault->setToolTip(QCoreApplication::translate("TonemappingPanel", "<html><head/><body><p>Restore pregamma's default value (1)</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        pregammadefault->setText(QString());
#if QT_CONFIG(tooltip)
        pregammadsb->setToolTip(QCoreApplication::translate("TonemappingPanel", "Gamma applied before tonemapping", nullptr));
#endif // QT_CONFIG(tooltip)
        label_10->setText(QCoreApplication::translate("TonemappingPanel", "Pos&t-saturation", nullptr));
#if QT_CONFIG(tooltip)
        postsaturationdefault->setToolTip(QCoreApplication::translate("TonemappingPanel", "<html><head/><body><p>Restore post-saturation's default value (1)</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_12->setText(QCoreApplication::translate("TonemappingPanel", "Post-gamma", nullptr));
#if QT_CONFIG(tooltip)
        postgammadefault->setToolTip(QCoreApplication::translate("TonemappingPanel", "<html><head/><body><p>Restore postgamma's default value (1)</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        postgammadefault->setText(QCoreApplication::translate("TonemappingPanel", "...", nullptr));
        processingToolBox->setItemText(processingToolBox->indexOf(page), QCoreApplication::translate("TonemappingPanel", "Processing", nullptr));
#if QT_CONFIG(tooltip)
        groupSaveLoadTMOsetting->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        groupSaveLoadTMOsetting->setWhatsThis(QCoreApplication::translate("TonemappingPanel", "Here you can load and save a tone mapping settings file.<br>You can also apply the contents of the currently loaded settings file.", nullptr));
#endif // QT_CONFIG(whatsthis)
        groupSaveLoadTMOsetting->setTitle(QCoreApplication::translate("TonemappingPanel", "Tone Mapping Settings", nullptr));
#if QT_CONFIG(tooltip)
        savesettingsbutton->setToolTip(QCoreApplication::translate("TonemappingPanel", "Save current parameters to a text file", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        savesettingsbutton->setWhatsThis(QCoreApplication::translate("TonemappingPanel", "Save current parameters (pregamma and TMO) to a text file.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        loadsettingsbutton->setToolTip(QCoreApplication::translate("TonemappingPanel", "Load an existing text file containing pregamma and TMO settings", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        loadsettingsbutton->setWhatsThis(QCoreApplication::translate("TonemappingPanel", "Load an existing text file containing pregamma and TMO settings.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        loadButton->setToolTip(QCoreApplication::translate("TonemappingPanel", "Load saved parameters", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        saveButton->setToolTip(QCoreApplication::translate("TonemappingPanel", "Save current parameters", nullptr));
#endif // QT_CONFIG(tooltip)
        groupBoxExport->setTitle(QCoreApplication::translate("TonemappingPanel", "Export", nullptr));
        queueButton->setText(QCoreApplication::translate("TonemappingPanel", "Fast export", nullptr));
#if QT_CONFIG(tooltip)
        lblOpenQueue->setToolTip(QCoreApplication::translate("TonemappingPanel", "Opens the current export directory. This can be changed in the preferences!", nullptr));
#endif // QT_CONFIG(tooltip)
        lblOpenQueue->setText(QCoreApplication::translate("TonemappingPanel", "<html><head/><body><p><a href=\"Open\"><span style=\" text-decoration: underline; color:#0000ff;\">Open</span></a></p></body></html>", nullptr));
        processingToolBox->setItemText(processingToolBox->indexOf(page_2), QCoreApplication::translate("TonemappingPanel", "Settings", nullptr));
        (void)TonemappingPanel;
    } // retranslateUi

};

namespace Ui {
    class TonemappingPanel: public Ui_TonemappingPanel {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_TONEMAPPINGPANEL_H
